@@ -30,6 +30,7 @@
 #include <QTimer>
 #include <QMap>
 #include <vlc/vlc.h>
+#include <vlc/libvlc_version.h>
 
 #include "../configuration.h"
 #include "vlcmediawidget.h"
@@ -89,6 +90,9 @@ bool VlcMediaWidget::init()
 	libvlc_event_e eventTypes[] = { libvlc_MediaPlayerEncounteredError,
 		libvlc_MediaPlayerEndReached, libvlc_MediaPlayerLengthChanged,
 		libvlc_MediaPlayerSeekableChanged, libvlc_MediaPlayerStopped,
+#if LIBVLC_VERSION_MAJOR > 2
+		libvlc_MediaPlayerESAdded, libvlc_MediaPlayerESDeleted,
+#endif
 		libvlc_MediaPlayerTimeChanged };
 
 	for (uint i = 0; i < (sizeof(eventTypes) / sizeof(eventTypes[0])); ++i) {
@@ -330,6 +334,7 @@ void VlcMediaWidget::setCurrentSubtitle(int currentSubtitle)
 
 	QMap<int, int>::const_iterator i = subtitleId.constBegin();
 	while (i != subtitleId.constEnd()) {
+		qDebug("Subtitle #%d, key: %d", i.value(), i.key());
 		if (i.value() == currentSubtitle) {
 			requestedSubtitle = i.key();
 			break;
@@ -337,15 +342,41 @@ void VlcMediaWidget::setCurrentSubtitle(int currentSubtitle)
 		i++;
 	}
 
+	qDebug("Try to set subtitle #%d, id %d", currentSubtitle, requestedSubtitle);
 	libvlc_video_set_spu(vlcMediaPlayer, requestedSubtitle);
+
+	/* Print what it was actually selected */
+	libvlc_track_description_t *track = libvlc_video_get_spu_description(vlcMediaPlayer);
+	while (track != NULL) {
+		QString subtitle = QString::fromUtf8(track->psz_name);
+
+		if (subtitle.isEmpty()) {
+			subtitle = i18n("Subtitle %1", track->i_id);
+		}
+
+		if (track->i_id == requestedSubtitle)
+			qDebug("Subtitle set to id %d: %s", track->i_id, qPrintable(subtitle));
+		track = track->p_next;
+	}
+	libvlc_track_description_list_release(track);
+
 }
 
-void VlcMediaWidget::setExternalSubtitle(const QUrl &subtitleUrl)
+void VlcMediaWidget::setExternalSubtitle(const QUrl &url)
 {
+	QString fname = url.toLocalFile();
+
+#if LIBVLC_VERSION_MAJOR > 2
+	if (libvlc_media_player_add_slave(vlcMediaPlayer,
+					  libvlc_media_slave_type_subtitle,
+					  url.toEncoded().constData(),
+					  true) == 0)
+		qWarning("Cannot set subtitle file %s", qPrintable(fname));
+#else
 	if (libvlc_video_set_subtitle_file(vlcMediaPlayer,
-	    subtitleUrl.toEncoded().constData()) == 0) {
-		qWarning("Cannot set subtitle file %s", qPrintable(subtitleUrl.toDisplayString()));
-	}
+					   qPrintable(fname)) == 0)
+		qWarning("Cannot set subtitle file %s", qPrintable(fname));
+#endif
 }
 
 void VlcMediaWidget::setCurrentTitle(int currentTitle)
@@ -535,6 +566,7 @@ void VlcMediaWidget::updateSubtitles()
 		// currentSubtitle
 		subtitleId[track->i_id] = ++i;
 		subtitles.append(subtitle);
+		qDebug("Got subtitle id#%d: %s", track->i_id, qPrintable(subtitle));
 		track = track->p_next;
 	}
 	libvlc_track_description_list_release(track);
@@ -608,6 +640,10 @@ void VlcMediaWidget::vlcEvent(const libvlc_event_t *event)
 	PendingUpdates pendingUpdatesToBeAdded = 0;
 
 	switch (event->type) {
+#if LIBVLC_VERSION_MAJOR > 2
+	case libvlc_MediaPlayerESAdded:
+	case libvlc_MediaPlayerESDeleted:
+#endif
 	case libvlc_MediaMetaChanged:
 		pendingUpdatesToBeAdded = Metadata | Subtitles;
 		break;
