@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -25,7 +26,6 @@
 
 #include <KConfigGroup>
 #include <KIO/Job>
-#include <KLocalizedString>
 #include <QBoxLayout>
 #include <QButtonGroup>
 #include <QCheckBox>
@@ -81,7 +81,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	gridLayout->addWidget(recordingFolderEdit, 0, 1);
 
 	QToolButton *toolButton = new QToolButton(widget);
-	toolButton->setIcon(QIcon::fromTheme(QLatin1String("document-open-folder")));
+	toolButton->setIcon(QIcon::fromTheme(QLatin1String("document-open-folder"), QIcon(":document-open-folder")));
 	toolButton->setToolTip(i18n("Select Folder"));
 	connect(toolButton, SIGNAL(clicked()), this, SLOT(changeRecordingFolder()));
 	gridLayout->addWidget(toolButton, 0, 2);
@@ -93,7 +93,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	gridLayout->addWidget(timeShiftFolderEdit, 1, 1);
 
 	toolButton = new QToolButton(widget);
-	toolButton->setIcon(QIcon::fromTheme(QLatin1String("document-open-folder")));
+	toolButton->setIcon(QIcon::fromTheme(QLatin1String("document-open-folder"), QIcon(":document-open-folder")));
 	toolButton->setToolTip(i18n("Select Folder"));
 	connect(toolButton, SIGNAL(clicked()), this, SLOT(changeTimeShiftFolder()));
 	gridLayout->addWidget(toolButton, 1, 2);
@@ -123,15 +123,14 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 
 	gridLayout->addWidget(namingFormat, 4, 1);
 
-	validPixmap = QIcon::fromTheme(QLatin1String("dialog-ok-apply")).pixmap(22);
-	invalidPixmap = QIcon::fromTheme(QLatin1String("dialog-cancel")).pixmap(22);
+	validPixmap = QIcon::fromTheme(QLatin1String("dialog-ok-apply"), QIcon(":dialog-ok-apply")).pixmap(22);
+	invalidPixmap = QIcon::fromTheme(QLatin1String("dialog-cancel"), QIcon(":dialog-cancel")).pixmap(22);
 
 	namingFormatValidLabel = new QLabel(widget);
 	namingFormatValidLabel->setPixmap(validPixmap);
 	gridLayout->addWidget(namingFormatValidLabel, 4,2);
 
-
-	gridLayout->addWidget(new QLabel(i18n("Action after recording finishes:")),	5, 0);
+	gridLayout->addWidget(new QLabel(i18n("Action after recording finishes.")),	5, 0);
 
 	actionAfterRecordingLineEdit = new QLineEdit(widget);
 	actionAfterRecordingLineEdit->setText(manager->getActionAfterRecording());
@@ -154,11 +153,15 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	createInfoFileBox->setChecked(manager->createInfoFile());
 	gridLayout->addWidget(createInfoFileBox, 2, 1);
 
+#if 0
+	// FIXME: this functionality is not working. Comment it out
+
 	gridLayout->addWidget(new QLabel(i18n("Scan channels when idle to fetch fresh EPG data:")),
 		3, 0);
 	scanWhenIdleBox = new QCheckBox(widget);
 	scanWhenIdleBox->setChecked(manager->isScanWhenIdle());
 	gridLayout->addWidget(scanWhenIdleBox, 3, 1);
+#endif
 
 	QFrame *frame = new QFrame(widget);
 	frame->setFrameShape(QFrame::HLine);
@@ -180,47 +183,18 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	frame->setFrameShape(QFrame::HLine);
 	boxLayout->addWidget(frame);
 
-	boxLayout->addWidget(new QLabel(i18n("Your position (only needed for USALS rotor)")));
-
 	boxLayout->addLayout(gridLayout);
 
-	gridLayout = new QGridLayout();
-	gridLayout->addWidget(new QLabel(i18n("Latitude:")), 0, 0);
-	gridLayout->addWidget(new QLabel(i18n("[S -90 ... 90 N]")), 0, 1);
-
-	latitudeEdit = new QLineEdit(widget);
-	latitudeEdit->setText(QString::number(manager->getLatitude(), 'g', 10));
-	connect(latitudeEdit, SIGNAL(textChanged(QString)), this, SLOT(latitudeChanged(QString)));
-	gridLayout->addWidget(latitudeEdit, 0, 2);
-
 	QStyleOptionTab option;
 	option.initFrom(tabWidget);
 	int metric = style()->pixelMetric(QStyle::PM_SmallIconSize, &option, tabWidget);
 
-	validPixmap = QIcon::fromTheme(QLatin1String("dialog-ok-apply")).pixmap(metric);
-	invalidPixmap = QIcon::fromTheme(QLatin1String("dialog-cancel")).pixmap(metric);
-
-	latitudeValidLabel = new QLabel(widget);
-	latitudeValidLabel->setPixmap(validPixmap);
-	gridLayout->addWidget(latitudeValidLabel, 0, 3);
-
-	gridLayout->addWidget(new QLabel(i18n("Longitude:")), 1, 0);
-	gridLayout->addWidget(new QLabel(i18n("[W -180 ... 180 E]")), 1, 1);
-
-	longitudeEdit = new QLineEdit(widget);
-	longitudeEdit->setText(QString::number(manager->getLongitude(), 'g', 10));
-	connect(longitudeEdit, SIGNAL(textChanged(QString)),
-		this, SLOT(longitudeChanged(QString)));
-	gridLayout->addWidget(longitudeEdit, 1, 2);
-
-	longitudeValidLabel = new QLabel(widget);
-	longitudeValidLabel->setPixmap(validPixmap);
-	gridLayout->addWidget(longitudeValidLabel, 1, 3);
-	boxLayout->addLayout(gridLayout);
+	validPixmap = QIcon::fromTheme(QLatin1String("dialog-ok-apply"), QIcon(":dialog-ok-apply")).pixmap(metric);
+	invalidPixmap = QIcon::fromTheme(QLatin1String("dialog-cancel"), QIcon(":dialog-cancel")).pixmap(metric);
 
 	boxLayout->addStretch();
 
-	tabWidget->addTab(widget, QIcon::fromTheme(QLatin1String("configure")), i18n("General Options"));
+	tabWidget->addTab(widget, QIcon::fromTheme(QLatin1String("configure"), QIcon(":configure")), i18n("General Options"));
 
 	QWidget *widgetAutomaticRecording = new QWidget(tabWidget);
 	QBoxLayout *boxLayoutAutomaticRecording = new QVBoxLayout(widgetAutomaticRecording);
@@ -253,7 +227,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 	boxLayoutAutomaticRecording->addLayout(buttonGrid);
 	boxLayoutAutomaticRecording->addLayout(regexGrid);
 
-	tabWidget->addTab(widgetAutomaticRecording, QIcon::fromTheme(QLatin1String("configure")),
+	tabWidget->addTab(widgetAutomaticRecording, QIcon::fromTheme(QLatin1String("configure"), QIcon(":configure")),
 			i18n("Automatic Recording"));
 	//
 
@@ -267,7 +241,7 @@ DvbConfigDialog::DvbConfigDialog(DvbManager *manager_, QWidget *parent) : QDialo
 			this, SLOT(moveRight(DvbConfigPage*)));
 		connect(configPage, SIGNAL(remove(DvbConfigPage*)),
 			this, SLOT(remove(DvbConfigPage*)));
-		tabWidget->addTab(configPage, QIcon::fromTheme(QLatin1String("video-television")), i18n("Device %1", i));
+		tabWidget->addTab(configPage, QIcon::fromTheme(QLatin1String("video-television"), QIcon(":video-television")), i18n("Device %1", i));
 		configPages.append(configPage);
 		++i;
 	}
@@ -378,7 +352,7 @@ void DvbConfigDialog::removeWidgets(QGridLayout *layout, int row, int column, bo
 void DvbConfigDialog::initRegexButtons(QGridLayout *buttonGrid)
 {
 	QWidgetAction *action = new QWidgetAction(tabWidget);
-	action->setIcon(QIcon::fromTheme(QLatin1String("list-add")));
+	action->setIcon(QIcon::fromTheme(QLatin1String("list-add"), QIcon(":list-add")));
 	action->setText(i18nc("@action", "Add new Regex"));
 
 	connect(action, SIGNAL(triggered()), this, SLOT(newRegex()));
@@ -389,7 +363,7 @@ void DvbConfigDialog::initRegexButtons(QGridLayout *buttonGrid)
 	pushButtonAdd->setToolTip(i18n("Add another regular expression."));
 
 	action = new QWidgetAction(tabWidget);
-	action->setIcon(QIcon::fromTheme(QLatin1String("edit-delete")));
+	action->setIcon(QIcon::fromTheme(QLatin1String("edit-delete"), QIcon(":edit-delete")));
 	action->setText(i18nc("@action", "Remove Regex"));
 	connect(action, SIGNAL(triggered()), this, SLOT(removeRegex()));
 	tabWidget->addAction(action);
@@ -410,11 +384,11 @@ void DvbConfigDialog::removeRegex()
 	}
 	foreach(RegexInputLine *inputLine, copyList)
 	{
-		qInfo() << "DvbConfigDialog::removeRegex: list:";
+		qDebug("list:");
 		if (inputLine->checkBox->isChecked()){
-			qInfo() << "DvbConfigDialog::removeRegex: checked:";
+			qDebug("checked:");
 			if (regexInputList.removeOne(inputLine)) {
-				qInfo() << "DvbConfigDialog::removeRegex: removed:";
+				qDebug("removed:");
 			}
 		}
 	}
@@ -448,7 +422,7 @@ void DvbConfigDialog::removeRegex()
 	boxLayoutAutomaticRecording->addLayout(buttonGrid);
 	boxLayoutAutomaticRecording->addLayout(regexGrid);
 	tabWidget->removeTab(1);
-	tabWidget->addTab(widgetAutomaticRecording, QIcon::fromTheme(QLatin1String("configure")), i18n("Automatic Recording"));
+	tabWidget->addTab(widgetAutomaticRecording, QIcon::fromTheme(QLatin1String("configure"), QIcon(":configure")), i18n("Automatic Recording"));
 	tabWidget->move(tabWidget->count()-1, 1);
 	tabWidget->setCurrentIndex(1);
 }
@@ -459,30 +433,6 @@ void DvbConfigDialog::openScanFile()
 	QDesktopServices::openUrl(QUrl(file));
 }
 
-void DvbConfigDialog::latitudeChanged(const QString &text)
-{
-	bool ok;
-	toLatitude(text, &ok);
-
-	if (ok) {
-		latitudeValidLabel->setPixmap(validPixmap);
-	} else {
-		latitudeValidLabel->setPixmap(invalidPixmap);
-	}
-}
-
-void DvbConfigDialog::longitudeChanged(const QString &text)
-{
-	bool ok;
-	toLongitude(text, &ok);
-
-	if (ok) {
-		longitudeValidLabel->setPixmap(validPixmap);
-	} else {
-		longitudeValidLabel->setPixmap(invalidPixmap);
-	}
-}
-
 void DvbConfigDialog::namingFormatChanged(QString text)
 {
 	QString temp = text.replace("%year", " ");
@@ -522,7 +472,7 @@ void DvbConfigDialog::moveLeft(DvbConfigPage *configPage)
 	}
 
 	// configPages and tabWidget indexes differ by two
-	tabWidget->insertTab(index + 1, configPages.at(index - 1), QIcon::fromTheme(QLatin1String("video-television")),
+	tabWidget->insertTab(index + 1, configPages.at(index - 1), QIcon::fromTheme(QLatin1String("video-television"), QIcon(":video-television")),
 		i18n("Device %1", index));
 	tabWidget->setTabText(index + 2, i18n("Device %1", index + 1));
 	tabWidget->setCurrentIndex(index + 1);
@@ -549,7 +499,7 @@ void DvbConfigDialog::moveRight(DvbConfigPage *configPage)
 	}
 
 	// configPages and tabWidget indexes differ by two
-	tabWidget->insertTab(index + 1, configPages.at(index - 1), QIcon::fromTheme(QLatin1String("video-television")),
+	tabWidget->insertTab(index + 1, configPages.at(index - 1), QIcon::fromTheme(QLatin1String("video-television"), QIcon(":video-television")),
 		i18n("Device %1", index));
 	tabWidget->setTabText(index + 2, i18n("Device %1", index + 1));
 	tabWidget->setCurrentIndex(index + 2);
@@ -579,38 +529,6 @@ void DvbConfigDialog::remove(DvbConfigPage *configPage)
 	}
 }
 
-double DvbConfigDialog::toLatitude(const QString &text, bool *ok)
-{
-	if (text.isEmpty()) {
-		*ok = true;
-		return 0;
-	}
-
-	double value = text.toDouble(ok);
-
-	if (qAbs(value) > 90) {
-		*ok = false;
-	}
-
-	return value;
-}
-
-double DvbConfigDialog::toLongitude(const QString &text, bool *ok)
-{
-	if (text.isEmpty()) {
-		*ok = true;
-		return 0;
-	}
-
-	double value = text.toDouble(ok);
-
-	if (qAbs(value) > 180) {
-		*ok = false;
-	}
-
-	return value;
-}
-
 void DvbConfigDialog::accept()
 {
 	manager->setRecordingFolder(recordingFolderEdit->text());
@@ -621,28 +539,18 @@ void DvbConfigDialog::accept()
 	manager->setEndMargin(endMarginBox->value() * 60);
 	manager->setOverride6937Charset(override6937CharsetBox->isChecked());
 	manager->setCreateInfoFile(createInfoFileBox->isChecked());
+#if 0
 	manager->setScanWhenIdle(scanWhenIdleBox->isChecked());
+#endif
 	manager->setRecordingRegexList(QStringList());
 	manager->setRecordingRegexPriorityList(QList<int>());
 
 	foreach (RegexInputLine *regexInputLine, regexInputList)
 	{
 		manager->addRecordingRegex(regexInputLine->lineEdit->text());
-		qInfo() << "DvbConfigDialog::accept: saved regex:" <<
-				regexInputLine->lineEdit->text();
+		qDebug("saved regex: %s", qPrintable(regexInputLine->lineEdit->text()));
 		manager->addRecordingRegexPriority(regexInputLine->spinBox->value());
-		qInfo() << "DvbConfigDialog::accept: saved priority:" <<
-				regexInputLine->spinBox->value();
-	}
-
-	bool latitudeOk;
-	bool longitudeOk;
-	double latitude = toLatitude(latitudeEdit->text(), &latitudeOk);
-	double longitude = toLongitude(longitudeEdit->text(), &longitudeOk);
-
-	if (latitudeOk && longitudeOk) {
-		manager->setLatitude(latitude);
-		manager->setLongitude(longitude);
+		qDebug("saved priority: %i", regexInputLine->spinBox->value());
 	}
 
 	QList<DvbDeviceConfigUpdate> configUpdates;
@@ -752,22 +660,22 @@ DvbConfigPage::DvbConfigPage(QWidget *parent, DvbManager *manager,
 	boxLayout->addWidget(new QLabel(i18n("Name: %1", deviceConfig->frontendName)));
 
 	QBoxLayout *horizontalLayout = new QHBoxLayout();
-	moveLeftButton = new QPushButton(QIcon::fromTheme(QLatin1String("arrow-left")), i18n("Move Left"), this);
+	moveLeftButton = new QPushButton(QIcon::fromTheme(QLatin1String("arrow-left"), QIcon(":arrow-left")), i18n("Move Left"), this);
 	connect(moveLeftButton, SIGNAL(clicked()), this, SLOT(moveLeft()));
 	horizontalLayout->addWidget(moveLeftButton);
 
 	if (deviceConfig->device != NULL) {
-		QPushButton *pushButton = new QPushButton(QIcon::fromTheme(QLatin1String("edit-undo")), i18n("Reset"), this);
+		QPushButton *pushButton = new QPushButton(QIcon::fromTheme(QLatin1String("edit-undo"), QIcon(":edit-undo")), i18n("Reset"), this);
 		connect(pushButton, SIGNAL(clicked()), this, SIGNAL(resetConfig()));
 		horizontalLayout->addWidget(pushButton);
 	} else {
 		QPushButton *pushButton =
-			new QPushButton(QIcon::fromTheme(QLatin1String("edit-delete")), i18nc("@action", "Remove"), this);
+			new QPushButton(QIcon::fromTheme(QLatin1String("edit-delete"), QIcon(":edit-delete")), i18nc("@action", "Remove"), this);
 		connect(pushButton, SIGNAL(clicked()), this, SLOT(removeConfig()));
 		horizontalLayout->addWidget(pushButton);
 	}
 
-	moveRightButton = new QPushButton(QIcon::fromTheme(QLatin1String("arrow-right")), i18n("Move Right"), this);
+	moveRightButton = new QPushButton(QIcon::fromTheme(QLatin1String("arrow-right"), QIcon(":arrow-right")), i18n("Move Right"), this);
 	connect(moveRightButton, SIGNAL(clicked()), this, SLOT(moveRight()));
 	horizontalLayout->addWidget(moveRightButton);
 	boxLayout->addLayout(horizontalLayout);
@@ -830,7 +738,7 @@ DvbConfigPage::DvbConfigPage(QWidget *parent, DvbManager *manager,
 			addHSeparator(i18n("DVB-S"));
 		}
 
-		dvbSObject = new DvbSConfigObject(this, boxLayout, manager, dvbSConfigs, dvbS2);
+		dvbSObject = new DvbSConfigObject(this, boxLayout, manager, dvbSConfigs, deviceConfig->device, dvbS2);
 	}
 
 	if ((transmissionTypes & DvbDevice::DvbT) != 0) {
@@ -1085,7 +993,7 @@ void DvbConfigObject::resetConfig()
 }
 
 DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbManager *manager,
-	const QList<DvbConfig> &configs, bool dvbS2) : QObject(parent_), parent(parent_)
+	const QList<DvbConfig> &configs, DvbDevice *device_, bool dvbS2) : QObject(parent_), parent(parent_), device(device_)
 {
 	if (!configs.isEmpty()) {
 		lnbConfig = new DvbConfigBase(*configs.at(0));
@@ -1146,7 +1054,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 
 		diseqcConfigs.append(DvbConfig(config));
 		lnbConfigs.append(new DvbSLnbConfigObject(timeoutBox, comboBox, pushButton,
-			config));
+			config, device));
 	}
 
 	// USALS rotor / Positions rotor
@@ -1155,7 +1063,7 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	connect(this, SIGNAL(setRotorVisible(bool)), pushButton, SLOT(setVisible(bool)));
 	layout->addWidget(pushButton, 6, 0);
 
-	lnbConfigs.append(new DvbSLnbConfigObject(timeoutBox, NULL, pushButton, lnbConfig));
+	lnbConfigs.append(new DvbSLnbConfigObject(timeoutBox, NULL, pushButton, lnbConfig, device));
 
 	sourceBox = new QComboBox(parent);
 	sourceBox->addItems(sources);
@@ -1208,6 +1116,57 @@ DvbSConfigObject::DvbSConfigObject(QWidget *parent_, QBoxLayout *boxLayout, DvbM
 	connect(pushButton, SIGNAL(clicked()), this, SLOT(removeSatellite()));
 	layout->addWidget(pushButton, 10, 0, 1, 2);
 
+	// Latitude/Longitude for USALS rotor
+
+	layout = new QGridLayout();
+
+	validPixmap = QIcon::fromTheme(QLatin1String("dialog-ok-apply")).pixmap(22);
+	invalidPixmap = QIcon::fromTheme(QLatin1String("dialog-cancel")).pixmap(22);
+
+	QLabel *label = new QLabel(i18n("Your position:"));
+	layout->addWidget(label);
+	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+
+	label = new QLabel(i18n("Latitude:"));
+	layout->addWidget(label, 1, 0);
+	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+
+	label = new QLabel(i18n("[S -90 ... 90 N]"));
+	layout->addWidget(label, 1, 1);
+	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+
+	latitudeEdit = new QLineEdit(parent);
+	latitudeEdit->setText(QString::number(lnbConfig->latitude, 'g', 10));
+	connect(latitudeEdit, SIGNAL(textChanged(QString)), this, SLOT(latitudeChanged(QString)));
+	layout->addWidget(latitudeEdit, 1, 2);
+	connect(this, SIGNAL(setUsalsVisible(bool)), latitudeEdit, SLOT(setVisible(bool)));
+
+	latitudeValidLabel = new QLabel(parent);
+	latitudeValidLabel->setPixmap(validPixmap);
+	layout->addWidget(latitudeValidLabel, 1, 3);
+	connect(this, SIGNAL(setUsalsVisible(bool)), latitudeValidLabel, SLOT(setVisible(bool)));
+
+	label = new QLabel(i18n("Longitude:"));
+	layout->addWidget(label, 2, 0);
+	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+
+	label = new QLabel(i18n("[W -180 ... 180 E]"));
+	layout->addWidget(label, 2, 1);
+	connect(this, SIGNAL(setUsalsVisible(bool)), label, SLOT(setVisible(bool)));
+
+	longitudeEdit = new QLineEdit(parent);
+	longitudeEdit->setText(QString::number(lnbConfig->longitude, 'g', 10));
+	connect(this, SIGNAL(setUsalsVisible(bool)), longitudeEdit, SLOT(setVisible(bool)));
+	connect(longitudeEdit, SIGNAL(textChanged(QString)),
+		this, SLOT(longitudeChanged(QString)));
+	layout->addWidget(longitudeEdit, 2, 2);
+
+	longitudeValidLabel = new QLabel(parent);
+	longitudeValidLabel->setPixmap(validPixmap);
+	layout->addWidget(longitudeValidLabel, 2, 3);
+	boxLayout->addLayout(layout);
+	connect(this, SIGNAL(setUsalsVisible(bool)), longitudeValidLabel, SLOT(setVisible(bool)));
+
 	configChanged(configBox->currentIndex());
 	connect(parent, SIGNAL(resetConfig()), this, SLOT(resetConfig()));
 }
@@ -1217,6 +1176,64 @@ DvbSConfigObject::~DvbSConfigObject()
 	delete lnbConfig;
 }
 
+
+void DvbSConfigObject::latitudeChanged(const QString &text)
+{
+	bool ok;
+	toLatitude(text, &ok);
+
+	if (ok) {
+		latitudeValidLabel->setPixmap(validPixmap);
+	} else {
+		latitudeValidLabel->setPixmap(invalidPixmap);
+	}
+}
+
+void DvbSConfigObject::longitudeChanged(const QString &text)
+{
+	bool ok;
+	toLongitude(text, &ok);
+
+	if (ok) {
+		longitudeValidLabel->setPixmap(validPixmap);
+	} else {
+		longitudeValidLabel->setPixmap(invalidPixmap);
+	}
+}
+
+
+double DvbSConfigObject::toLatitude(const QString &text, bool *ok)
+{
+	if (text.isEmpty()) {
+		*ok = true;
+		return 0;
+	}
+
+	double value = text.toDouble(ok);
+
+	if (qAbs(value) > 90) {
+		*ok = false;
+	}
+
+	return value;
+}
+
+double DvbSConfigObject::toLongitude(const QString &text, bool *ok)
+{
+	if (text.isEmpty()) {
+		*ok = true;
+		return 0;
+	}
+
+	double value = text.toDouble(ok);
+
+	if (qAbs(value) > 180) {
+		*ok = false;
+	}
+
+	return value;
+}
+
 void DvbSConfigObject::appendConfigs(QList<DvbConfig> &list)
 {
 	int index = configBox->currentIndex();
@@ -1244,6 +1261,17 @@ void DvbSConfigObject::appendConfigs(QList<DvbConfig> &list)
 			if (index == 1) {
 				// USALS rotor
 				config->configuration = DvbConfigBase::UsalsRotor;
+
+				bool latitudeOk;
+				bool longitudeOk;
+
+				double latitude = toLatitude(latitudeEdit->text(), &latitudeOk);
+				double longitude = toLongitude(longitudeEdit->text(), &longitudeOk);
+
+				if (latitudeOk && longitudeOk) {
+					config->latitude = latitude;
+					config->longitude = longitude;
+				}
 			} else {
 				// Positions rotor
 				config->configuration = DvbConfigBase::PositionsRotor;
@@ -1338,15 +1366,14 @@ DvbConfigBase *DvbSConfigObject::createConfig(int lnbNumber)
 	config->timeout = 1500;
 	config->configuration = DvbConfigBase::DiseqcSwitch;
 	config->lnbNumber = lnbNumber;
-	config->lowBandFrequency = 9750000;
-	config->switchFrequency = 11700000;
-	config->highBandFrequency = 10600000;
+	config->currentLnb = device->getLnbSatModels().at(0);
+	config->bpf = 0;
 	return config;
 }
 
 DvbSLnbConfigObject::DvbSLnbConfigObject(QSpinBox *timeoutSpinBox, QComboBox *sourceBox_,
-	QPushButton *configureButton_, DvbConfigBase *config_) : QObject(timeoutSpinBox),
-	sourceBox(sourceBox_), configureButton(configureButton_), config(config_)
+	QPushButton *configureButton_, DvbConfigBase *config_, DvbDevice *device_) : QObject(timeoutSpinBox),
+	sourceBox(sourceBox_), configureButton(configureButton_), config(config_), device(device_)
 {
 	connect(timeoutSpinBox, SIGNAL(valueChanged(int)), this, SLOT(timeoutChanged(int)));
 	connect(configureButton, SIGNAL(clicked()), this, SLOT(configure()));
@@ -1366,9 +1393,8 @@ DvbSLnbConfigObject::~DvbSLnbConfigObject()
 
 void DvbSLnbConfigObject::resetConfig()
 {
-	config->lowBandFrequency = 9750000;
-	config->switchFrequency = 11700000;
-	config->highBandFrequency = 10600000;
+	config->currentLnb = device->getLnbSatModels().at(0);
+	config->bpf = 0;
 
 	if (sourceBox != NULL) {
 		sourceBox->setCurrentIndex(0);
@@ -1398,14 +1424,14 @@ void DvbSLnbConfigObject::configure()
 {
 	QVBoxLayout *mainLayout = new QVBoxLayout();
 
-	QDialog *dialog = new QDialog(configureButton);
+	dialog = new QDialog(configureButton);
 	dialog->setAttribute(Qt::WA_DeleteOnClose);
 	dialog->setWindowTitle(i18n("LNB Settings"));
 	dialog->setLayout(mainLayout);
 
 	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-	connect(buttonBox, SIGNAL(accepted()), this, SLOT(dialogAccepted()));
-	connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &DvbSLnbConfigObject::dialogAccepted);
+	connect(buttonBox, &QDialogButtonBox::rejected, dialog, &QDialog::reject);
 
 	QWidget *mainWidget = new QWidget(dialog);
 	QGridLayout *gridLayout = new QGridLayout(mainWidget);
@@ -1415,161 +1441,119 @@ void DvbSLnbConfigObject::configure()
 	lnbSelectionGroup->setExclusive(true);
 	connect(lnbSelectionGroup, SIGNAL(buttonClicked(int)), this, SLOT(selectType(int)));
 
-	QRadioButton *radioButton = new QRadioButton(i18n("Universal LNB"), mainWidget);
-	mainLayout->addWidget(radioButton);
-	lnbSelectionGroup->addButton(radioButton, 1);
-	gridLayout->addWidget(radioButton, 0, 0, 1, 2);
+	int i, size = device->getLnbSatModels().size();
 
-	radioButton = new QRadioButton(i18n("C-band LNB"), mainWidget);
-	mainLayout->addWidget(radioButton);
-	lnbSelectionGroup->addButton(radioButton, 2);
-	gridLayout->addWidget(radioButton, 1, 0, 1, 2);
+	currentType = -1;
 
-	radioButton = new QRadioButton(i18n("C-band Multipoint LNB"), mainWidget);
-	mainLayout->addWidget(radioButton);
-	lnbSelectionGroup->addButton(radioButton, 3);
-	gridLayout->addWidget(radioButton, 2, 0, 1, 2);
+	for (i = 0; i < size; i++) {
+		struct lnbSat lnb = device->getLnbSatModels().at(i);
+		QRadioButton *radioButton = new QRadioButton(lnb.name, mainWidget);
+		mainLayout->addWidget(radioButton);
+		lnbSelectionGroup->addButton(radioButton, i + 1);
+		gridLayout->addWidget(radioButton, i % ((size + 1) / 2), i / ((size + 1) / 2));
 
-	radioButton = new QRadioButton(i18n("Custom LNB"), mainWidget);
-	mainLayout->addWidget(radioButton);
-	lnbSelectionGroup->addButton(radioButton, 4);
-	gridLayout->addWidget(radioButton, 3, 0, 1, 2);
-
-	QFrame *frame = new QFrame(mainWidget);
-	mainLayout->addWidget(frame);
-	frame->setFrameShape(QFrame::HLine);
-	gridLayout->addWidget(frame, 4, 0, 1, 2);
-
-	lowBandLabel = new QLabel(mainWidget);
-	mainLayout->addWidget(lowBandLabel);
-	gridLayout->addWidget(lowBandLabel, 5, 0);
-
-	switchLabel = new QLabel(i18n("Switch frequency (MHz)"), mainWidget);
-	mainLayout->addWidget(switchLabel);
-	gridLayout->addWidget(switchLabel, 6, 0);
-
-	highBandLabel = new QLabel(mainWidget);
-	mainLayout->addWidget(highBandLabel);
-	gridLayout->addWidget(highBandLabel, 7, 0);
-
-	lowBandSpinBox = new QSpinBox(mainWidget);
-	mainLayout->addWidget(lowBandSpinBox);
-	lowBandSpinBox->setRange(0, 13000);
-	lowBandSpinBox->setValue(config->lowBandFrequency / 1000);
-	gridLayout->addWidget(lowBandSpinBox, 5, 1);
-
-	switchSpinBox = new QSpinBox(mainWidget);
-	mainLayout->addWidget(switchSpinBox);
-	switchSpinBox->setRange(0, 13000);
-	switchSpinBox->setValue(config->switchFrequency / 1000);
-	gridLayout->addWidget(switchSpinBox, 6, 1);
-
-	highBandSpinBox = new QSpinBox(mainWidget);
-	mainLayout->addWidget(highBandSpinBox);
-	highBandSpinBox->setRange(0, 13000);
-	highBandSpinBox->setValue(config->highBandFrequency / 1000);
-	gridLayout->addWidget(highBandSpinBox, 7, 1);
-
-	gridLayout->addItem(new QSpacerItem(0, 0), 8, 0, 1, 2);
-	gridLayout->setRowStretch(8, 1);
-
-	int lnbType;
-
-	if ((config->lowBandFrequency == 9750000) && (config->switchFrequency == 11700000) &&
-	    (config->highBandFrequency == 10600000)) {
-		lnbType = 1;
-	} else if ((config->lowBandFrequency == 5150000) && (config->switchFrequency == 0) &&
-		   (config->highBandFrequency == 0)) {
-		lnbType = 2;
-	} else if ((config->lowBandFrequency == 5750000) && (config->switchFrequency == 0) &&
-		   (config->highBandFrequency == 5150000)) {
-		lnbType = 3;
-	} else {
-		lnbType = 4;
+		if (config->currentLnb.alias.isEmpty() || config->currentLnb.alias == lnb.alias) {
+			radioButton->setChecked(true);
+			config->currentLnb = lnb;
+			currentType = i + 1;
+		}
 	}
 
-	currentType = 4;
-	lnbSelectionGroup->button(lnbType)->setChecked(true);
-	selectType(lnbType);
+	// shouldn't happen, except if the config file has an invalid LNBf
+	if (currentType < 0) {
+		config->currentLnb = device->getLnbSatModels().at(0);
+		currentType = 1;
+	}
+
+	QFrame *frame = new QFrame(mainWidget);
+	frame->setFrameShape(QFrame::VLine);
+	gridLayout->addWidget(frame, 0, 3, 6, 1);
+
+	// FIXME: Those are actually the IF frequencies
+
+	lowBandLabel = new QLabel(i18n("Low frequency (KHz)"), mainWidget);
+	gridLayout->addWidget(lowBandLabel, 0, 4);
+	lowBandSpinBox = new QSpinBox(mainWidget);
+	gridLayout->addWidget(lowBandSpinBox, 0, 5);
+	lowBandSpinBox->setRange(0, 15000);
+	lowBandSpinBox->setValue(config->currentLnb.lowFreq);
+	lowBandSpinBox->setEnabled(false);
+
+	highBandLabel = new QLabel(i18n("High frequency (MHz)"), mainWidget);
+	gridLayout->addWidget(highBandLabel, 1, 4);
+	highBandSpinBox = new QSpinBox(mainWidget);
+	gridLayout->addWidget(highBandSpinBox, 1, 5);
+	highBandSpinBox->setRange(0, 15000);
+	highBandSpinBox->setValue(config->currentLnb.highFreq);
+	highBandSpinBox->setEnabled(false);
+
+	switchLabel = new QLabel(i18n("Switch frequency (MHz)"), mainWidget);
+	gridLayout->addWidget(switchLabel, 2, 4);
+	switchSpinBox = new QSpinBox(mainWidget);
+	gridLayout->addWidget(switchSpinBox, 2, 5);
+	switchSpinBox->setRange(0, 15000);
+	switchSpinBox->setValue(config->currentLnb.rangeSwitch);
+	switchSpinBox->setEnabled(false);
+
+	lowRangeLabel = new QLabel(i18n("Low range: %1 MHz to %2 MHz", config->currentLnb.freqRange[0].low, config->currentLnb.freqRange[0].high), mainWidget);
+	gridLayout->addWidget(lowRangeLabel, 3, 4, 1, 2);
+
+	highRangeLabel = new QLabel(mainWidget);
+	gridLayout->addWidget(highRangeLabel, 4, 5, 1, 2);
+
+	selectType(currentType);
 
 	mainLayout->addWidget(buttonBox);
 
 	dialog->setModal(true);
 	dialog->show();
+
 }
 
 void DvbSLnbConfigObject::selectType(int type)
 {
-	switch (type) {
-	case 1:
-		lowBandSpinBox->setValue(9750);
-		switchSpinBox->setValue(11700);
-		highBandSpinBox->setValue(10600);
-		break;
+	struct lnbSat lnb = device->getLnbSatModels().at(type - 1);
 
-	case 2:
-		lowBandSpinBox->setValue(5150);
-		switchSpinBox->setValue(0);
-		highBandSpinBox->setValue(0);
-		break;
 
-	case 3:
-		lowBandSpinBox->setValue(5750);
-		switchSpinBox->setValue(0);
-		highBandSpinBox->setValue(5150);
-		break;
+	lowBandSpinBox->setValue(lnb.lowFreq);
+	if (!lnb.lowFreq) {
+		lowBandLabel->hide();
+		lowBandSpinBox->hide();
+	} else {
+		lowBandLabel->show();
+		lowBandSpinBox->show();
 	}
 
-	if (switchSpinBox->value() != 0) {
-		if (currentType != 1) {
-			lowBandLabel->setText(i18n("Low band LOF (MHz)"));
+	highBandSpinBox->setValue(lnb.highFreq);
+	if (!lnb.highFreq) {
+		highBandLabel->hide();
+		highBandSpinBox->hide();
+	} else {
+		highBandLabel->show();
+		highBandSpinBox->show();
+	}
 
-			switchLabel->show();
-			switchSpinBox->show();
+	switchSpinBox->setValue(lnb.rangeSwitch);
+	if (!lnb.rangeSwitch) {
+		switchLabel->hide();
+		switchSpinBox->hide();
+	} else {
+		switchLabel->show();
+		switchSpinBox->show();
+	}
 
-			highBandLabel->setText(i18n("High band LOF (MHz)"));
-			highBandLabel->show();
-			highBandSpinBox->show();
-		}
-	} else if (highBandSpinBox->value() != 0) {
-		if (currentType != 3) {
-			lowBandLabel->setText(i18n("Horizontal LOF (MHz)"));
+	lowRangeLabel->setText(i18n("Low range: %1 MHz to %2 MHz", lnb.freqRange[0].low, lnb.freqRange[0].high));
 
-			switchLabel->hide();
-			switchSpinBox->hide();
-
-			highBandLabel->setText(i18n("Vertical LOF (MHz)"));
-			highBandLabel->show();
-			highBandSpinBox->show();
+	if (!lnb.freqRange[1].high) {
+		if (!lnb.highFreq) {
+			highRangeLabel->hide();
+		} else {
+			highRangeLabel->setText(i18n("Bandstacked"));
+			highRangeLabel->show();
 		}
 	} else {
-		if (currentType != 2) {
-			lowBandLabel->setText(i18n("LOF (MHz)"));
-
-			switchLabel->hide();
-			switchSpinBox->hide();
-
-			highBandLabel->hide();
-			highBandSpinBox->hide();
-		}
-	}
-
-	if ((currentType == 4) != (type == 4)) {
-		if (type == 4) {
-			lowBandLabel->setEnabled(true);
-			switchLabel->setEnabled(true);
-			highBandLabel->setEnabled(true);
-			lowBandSpinBox->setEnabled(true);
-			switchSpinBox->setEnabled(true);
-			highBandSpinBox->setEnabled(true);
-		} else {
-			lowBandLabel->setEnabled(false);
-			switchLabel->setEnabled(false);
-			highBandLabel->setEnabled(false);
-			lowBandSpinBox->setEnabled(false);
-			switchSpinBox->setEnabled(false);
-			highBandSpinBox->setEnabled(false);
-		}
+		highRangeLabel->setText(i18n("High range: %1 MHz to %2 MHz", lnb.freqRange[1].low, lnb.freqRange[1].high));
+		highRangeLabel->show();
 	}
 
 	currentType = type;
@@ -1577,7 +1561,8 @@ void DvbSLnbConfigObject::selectType(int type)
 
 void DvbSLnbConfigObject::dialogAccepted()
 {
-	config->lowBandFrequency = lowBandSpinBox->value() * 1000;
-	config->switchFrequency = switchSpinBox->value() * 1000;
-	config->highBandFrequency = highBandSpinBox->value() * 1000;
+	config->currentLnb = device->getLnbSatModels().at(currentType - 1);
+	qDebug() << "Selected LNBf:" << config->currentLnb.alias;
+
+	dialog->accept();
 }
