@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -76,7 +77,7 @@ void DvbSectionFilterInternal::processData(const char data[188])
 {
 	if ((data[3] & 0x10) == 0) {
 		// no payload
-		qInfo() << "DvbSectionFilterInternal::processData: no payload";
+		qDebug("MPEG-TS session doesn't have a payload");
 		return;
 	}
 
@@ -84,12 +85,12 @@ void DvbSectionFilterInternal::processData(const char data[188])
 
 	if (bufferValid) {
 		if (continuity == continuityCounter) {
-			qInfo() << "DvbSectionFilterInternal::processData: duplicate packets";
+			qDebug("Section duplication: received %d, expecting %d", continuity, continuityCounter + 1);
 			return;
 		}
 
 		if (continuity != ((continuityCounter + 1) & 0x0f)) {
-			qInfo() << "DvbSectionFilterInternal::processData: discontinuity";
+			qDebug("Section discontinuity: received %d, expecting %d", continuity, continuityCounter + 1);
 			bufferValid = false;
 		}
 	}
@@ -109,7 +110,7 @@ void DvbSectionFilterInternal::processData(const char data[188])
 		unsigned char length = data[4];
 
 		if (length > 182) {
-			qInfo() << "DvbSectionFilterInternal::processData: no payload or corrupt";
+			qDebug("Received a section without  payload or corrupted");
 			return;
 		}
 
@@ -123,7 +124,7 @@ void DvbSectionFilterInternal::processData(const char data[188])
 		int pointer = quint8(payload[0]);
 
 		if (pointer >= payloadLength) {
-			qInfo() << "DvbSectionFilterInternal::processData: invalid pointer";
+			qDebug("Section with invalid payload pointer");
 			pointer = (payloadLength - 1);
 		}
 
@@ -156,7 +157,7 @@ void DvbSectionFilterInternal::processSections(bool force)
 
 		if ((end - it) < 3) {
 			if (force) {
-				qInfo() << "DvbSectionFilterInternal::processSections: stray data";
+				qDebug("Section with stray data");
 				it = end;
 			}
 
@@ -167,7 +168,7 @@ void DvbSectionFilterInternal::processSections(bool force)
 			static_cast<unsigned char>(it[2])) + 3);
 
 		if (force && (sectionEnd > end)) {
-			qInfo() << "DvbSectionFilterInternal::processSections: short section";
+			qDebug("Short section");
 			sectionEnd = end;
 		}
 
@@ -229,7 +230,7 @@ DvbDataDumper::DvbDataDumper()
 		QLatin1String(".bin"));
 
 	if (!open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		qInfo() << "DvbDataDumper::DvbDataDumper: cannot open" << fileName();
+		qWarning("Can't open %s", qPrintable(fileName()));
 	}
 }
 
@@ -306,70 +307,26 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 		return;
 	}
 
-	DvbTransponder intermediate = transponder;
-	DvbSTransponder *dvbSTransponder = NULL;
-	DvbS2Transponder *dvbS2Transponder = NULL;
 	bool moveRotor = false;
+	DvbTransponder intermediate = transponder;
 
-	if (transmissionType == DvbTransponderBase::DvbS) {
-		dvbSTransponder = intermediate.as<DvbSTransponder>();
-	} else {
-		// DVB-S2
-		dvbS2Transponder = intermediate.as<DvbS2Transponder>();
-		dvbSTransponder = dvbS2Transponder;
-	}
+	// DVB LNBf IF and DiSeqC switch settings
 
-	// parameters
+	int satNumber = 0;	// No DiseqC Switch
 
-	bool horPolar = (dvbSTransponder->polarization == DvbSTransponder::Horizontal) ||
-			(dvbSTransponder->polarization == DvbSTransponder::CircularLeft);
+	if (config->configuration == DvbConfigBase::DiseqcSwitch)
+		satNumber = config->lnbNumber + 1;
 
-	int frequency = dvbSTransponder->frequency;
-	bool highBand = false;
+	// FIXME: add support for SCR/Unicable
+	if (!backend->satSetup(config->currentLnb.alias, satNumber, 0))
+		return;
 
-	if (config->switchFrequency != 0) {
-		// dual LO (low / high)
-		if (frequency < config->switchFrequency) {
-			frequency = qAbs(frequency - config->lowBandFrequency);
-		} else {
-			frequency = qAbs(frequency - config->highBandFrequency);
-			highBand = true;
-		}
-	} else if (config->highBandFrequency != 0) {
-		// single LO (horizontal / vertical)
-		if (horPolar) {
-			frequency = qAbs(frequency - config->lowBandFrequency);
-		} else {
-			frequency = qAbs(frequency - config->highBandFrequency);
-		}
-	} else {
-		// single LO
-		frequency = qAbs(frequency - config->lowBandFrequency);
-	}
-
-	// tone off
-
-	backend->setTone(ToneOff);
-
-	// horizontal / circular left --> 18V ; vertical / circular right --> 13V
-
-	backend->setVoltage(horPolar ? Voltage18V : Voltage13V);
-
-	// diseqc / rotor
-
-	usleep(15000);
+	// rotor
 
 	switch (config->configuration) {
-	case DvbConfigBase::DiseqcSwitch: {
-		char cmd[] = { char(0xe0), 0x10, 0x38, 0x00 };
-		cmd[3] = 0xf0 | char(config->lnbNumber << 2) | (horPolar ? 2 : 0) | (highBand ? 1 : 0);
-		backend->sendMessage(cmd, sizeof(cmd));
-		usleep(15000);
-
-		backend->sendBurst(((config->lnbNumber & 0x1) == 0) ? BurstMiniA : BurstMiniB);
-		usleep(15000);
+	case DvbConfigBase::DiseqcSwitch:
+		// Everything was already prepared via satSetup().
 		break;
-	    }
 
 	case DvbConfigBase::UsalsRotor: {
 		QString source = config->scanSource;
@@ -386,15 +343,13 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 			orbitalPosition = (-source.toDouble(&ok));
 		}
 
-		if (!ok) {
-			qInfo() << "DvbDevice::tune: cannot extract orbital position from" <<
-				config->scanSource;
-		}
+		if (!ok)
+			qWarning("Can't extract orbital position from %s", qPrintable(config->scanSource));
 
 		double radius = 6378;
 		double semiMajorAxis = 42164;
-		double temp = (radius * cos(DvbManager::getLatitude() * M_PI / 180));
-		double temp2 = ((orbitalPosition - DvbManager::getLongitude()) * M_PI / 180);
+		double temp = (radius * cos(config->latitude * M_PI / 180));
+		double temp2 = ((orbitalPosition - config->longitude) * M_PI / 180);
 		double angle = (temp2 + atan(sin(temp2) / ((semiMajorAxis / temp) - cos(temp2))));
 		int value = 0;
 
@@ -409,6 +364,7 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 		}
 
 		char cmd[] = { char(0xe0), 0x31, 0x6e, char(value / 256), char(value % 256) };
+		usleep(15000);
 		backend->sendMessage(cmd, sizeof(cmd));
 		usleep(15000);
 		moveRotor = true;
@@ -417,6 +373,7 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 
 	case DvbConfigBase::PositionsRotor: {
 		char cmd[] = { char(0xe0), 0x31, 0x6b, char(config->lnbNumber) };
+		usleep(15000);
 		backend->sendMessage(cmd, sizeof(cmd));
 		usleep(15000);
 		moveRotor = true;
@@ -424,14 +381,8 @@ void DvbDevice::tune(const DvbTransponder &transponder)
 	    }
 	}
 
-	// low band --> tone off ; high band --> tone on
-
-	backend->setTone(highBand ? ToneOn : ToneOff);
-
 	// tune
 
-	dvbSTransponder->frequency = frequency;
-
 	if (backend->tune(intermediate)) {
 		if (!moveRotor) {
 			setDeviceState(DeviceTuning);
@@ -487,8 +438,8 @@ void DvbDevice::autoTune(const DvbTransponder &transponder)
 		// ISDB-T Currently, all ISDB-T tuners should support auto mode
 		isAuto = true;
 		tune(autoTransponder);
-	}else {
-		qInfo() << "DvbDevice::autoTune: can't do auto-tune for " << transmissionType;
+	} else {
+		qWarning("Can't do auto-tune for %d", transmissionType);
 		return;
 	}
 
@@ -516,8 +467,7 @@ bool DvbDevice::addPidFilter(int pid, DvbPidFilter *filter)
 	}
 
 	if (it->filters.contains(filter)) {
-		qInfo() << "DvbDevice::addPidFilter: "
-		    "using the same filter for the same pid more than once";
+		qInfo("Using the same filter for the same pid more than once");
 		return true;
 	}
 
@@ -542,8 +492,7 @@ bool DvbDevice::addSectionFilter(int pid, DvbSectionFilter *filter)
 	}
 
 	if (it->sectionFilters.contains(filter)) {
-		qInfo() << "DvbDevice::addSectionFilter: "
-		    "using the same filter for the same pid more than once";
+		qInfo("Using the same filter for the same pid more than once");
 		return true;
 	}
 
@@ -564,7 +513,7 @@ void DvbDevice::removePidFilter(int pid, DvbPidFilter *filter)
 	}
 
 	if (index < 0) {
-		qInfo() << "DvbDevice::removePidFilter: trying to remove a nonexistent filter";
+		qWarning("Trying to remove a nonexistent filter");
 		return;
 	}
 
@@ -590,7 +539,7 @@ void DvbDevice::removeSectionFilter(int pid, DvbSectionFilter *filter)
 	}
 
 	if (index < 0) {
-		qInfo() << "DvbDevice::removeSectionFilter: trying to remove a nonexistent filter";
+		qWarning("Trying to remove a nonexistent filter");
 		return;
 	}
 
@@ -609,7 +558,7 @@ void DvbDevice::startDescrambling(const QByteArray &pmtSectionData, QObject *use
 	DvbPmtSection pmtSection(pmtSectionData);
 
 	if (!pmtSection.isValid()) {
-		qInfo() << "DvbDevice::startDescrambling: pmt section is not valid";
+		qWarning("PMT section is invalid");
 	}
 
 	int serviceId = pmtSection.programNumber();
@@ -628,13 +577,13 @@ void DvbDevice::stopDescrambling(const QByteArray &pmtSectionData, QObject *user
 	DvbPmtSection pmtSection(pmtSectionData);
 
 	if (!pmtSection.isValid()) {
-		qInfo() << "DvbDevice::stopDescrambling: pmt section is not valid";
+		qWarning("PMT section is invalid");
 	}
 
 	int serviceId = pmtSection.programNumber();
 
 	if (!descramblingServices.contains(serviceId, user)) {
-		qInfo() << "DvbDevice::stopDescrambling: service has not been started";
+		qInfo("Service has not been started while stop descrambling");
 		return;
 	}
 
@@ -655,14 +604,14 @@ bool DvbDevice::getProps(DvbTransponder &transponder) const
 	return backend->getProps(transponder);
 }
 
-int DvbDevice::getSignal() const
+float DvbDevice::getSignal(DvbBackendDevice::Scale &scale) const
 {
-	return backend->getSignal();
+	return backend->getSignal(scale);
 }
 
-int DvbDevice::getSnr() const
+float DvbDevice::getSnr(DvbBackendDevice::Scale &scale) const
 {
-	return backend->getSnr();
+	return backend->getSnr(scale);
 }
 
 DvbTransponder DvbDevice::getAutoTransponder() const
@@ -725,7 +674,7 @@ void DvbDevice::frontendEvent()
 	DvbTransponderBase::TransmissionType transmissionType = autoTransponder.getTransmissionType();
 
 	if (backend->isTuned()) {
-		qInfo() << "DvbDevice::frontendEvent: tuning succeeded on freq=" << backend->getFrqMHz() << "MHz";
+		qDebug("tuning succeeded on %.2f MHz", backend->getFrqMHz());
 		frontendTimer.stop();
 		backend->getProps(autoTransponder);
 		setDeviceState(DeviceTuned);
@@ -740,7 +689,7 @@ void DvbDevice::frontendEvent()
 		frontendTimer.stop();
 
 		if (!isAuto) {
-			qInfo() << "DvbDevice::frontendEvent: tuning failed for freq=" << backend->getFrqMHz() << "MHz";
+			qDebug("tuning failed on %.2f MHz", backend->getFrqMHz());
 			setDeviceState(DeviceIdle);
 			autoTransponder.setTransmissionType(DvbTransponderBase::Invalid);
 			return;
@@ -753,12 +702,14 @@ void DvbDevice::frontendEvent()
 		 * it for DVB-T
 		 */
 		if (transmissionType == DvbTransponderBase::DvbT) {
-			DvbTTransponder *autoTTransponder = autoTransponder.as<DvbTTransponder>();
-			int signal = backend->getSignal();
+			DvbBackendDevice::Scale scale;
 
-			if ((signal != -1) && (signal < 15)) {
+			DvbTTransponder *autoTTransponder = autoTransponder.as<DvbTTransponder>();
+			float signal = backend->getSignal(scale);
+
+			if ((scale != DvbBackendDevice::NotSupported) && (signal < 15)) {
 				// signal too weak
-				qInfo() << "DvbDevice::frontendEvent: tuning failed (signal too weak) for freq=" << backend->getFrqMHz() << "MHz";
+				qInfo("Tuning failed (signal too weak) on %.2f MHz", backend->getFrqMHz());
 				setDeviceState(DeviceIdle);
 				autoTransponder.setTransmissionType(DvbTransponderBase::Invalid);
 				return;
@@ -856,7 +807,7 @@ void DvbDevice::frontendEvent()
 		if (!carry) {
 			tune(autoTransponder);
 		} else {
-			qInfo() << "DvbDevice::frontendEvent: tuning failed for freq=" << backend->getFrqMHz() << "MHz";;
+			qDebug("tuning failed on %.2f MHz", backend->getFrqMHz());;
 			setDeviceState(DeviceIdle);
 		}
 	}
@@ -898,7 +849,7 @@ void DvbDevice::stop()
 		foreach (DvbPidFilter *filter, it->filters) {
 			if ((filter != &dummyPidFilter) && (filter != dataDumper)) {
 				int pid = it.key();
-				qInfo() << "DvbDevice::stop: removing pending filter" << pid;
+				qDebug("removing pending filter %d", pid);
 				removePidFilter(pid, filter);
 			}
 		}
@@ -909,7 +860,7 @@ void DvbDevice::stop()
 		foreach (DvbSectionFilter *sectionFilter, it->sectionFilters) {
 			if (sectionFilter != &dummySectionFilter) {
 				int pid = it.key();
-				qInfo() << "DvbDevice::stop: removing pending filter" << pid;
+				qDebug("removing pending filter %d", pid);
 				removeSectionFilter(pid, sectionFilter);
 			}
 		}
