@@ -19,6 +19,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -32,17 +33,20 @@ extern "C" {
   #include <frontend.h>
   #include <poll.h>
   #include <stdlib.h>
+  #include <sys/syslog.h>
   #include <unistd.h>
   #include <vector>
   #include <sys/socket.h>
   #include <sys/un.h>
   #include <sys/types.h>
+  #include <sys/inotify.h>
   #include <sys/ioctl.h>
   #include <sys/stat.h>
-  #include <sys/inotify.h>
+  #include <sys/syslog.h>
 }
 
 #include <QFile>
+#include <QMessageLogger>
 #include <QRegularExpressionMatch>
 #include <Solid/Device>
 #include <Solid/DeviceNotifier>
@@ -65,33 +69,33 @@ DvbLinuxDevice::~DvbLinuxDevice()
 	stopDevice();
 }
 
-static const char loglevel[9][10] = {
-	{"EMERG"},
-	{"ALERT"},
-	{"CRITICAL"},
-	{"ERROR"},
-	{"WARNING"},
-	{"NOTICE"},
-	{"INFO"},
-	{"DEBUG"},
-	{"OTHER"},
-};
-
-#define loglevels ((int)(sizeof(loglevel)/sizeof(*loglevel)))
-
 static void dvbv5_log(int level, const char *fmt, ...)
 {
 	va_list ap;
 	char log[1024];
 
-	if (level >= loglevels)
-		level = loglevels - 1;
-
 	va_start(ap, fmt);
 	vsnprintf(log, sizeof(log), fmt, ap);
 	va_end(ap);
 
-	qInfo() << "DvbLinuxDevice::libdvbv5" << loglevel[level] << log;
+	switch(LOG_PRI(level)) {
+	case LOG_DEBUG:
+	case LOG_INFO:
+		qDebug("%s", log);
+		break;
+	case LOG_NOTICE:
+		qInfo("%s", log);
+		break;
+	case LOG_WARNING:
+		qWarning("%s", log);
+		break;
+	case LOG_ERR:
+	case LOG_CRIT:
+	case LOG_ALERT:
+	case LOG_EMERG:
+		qCritical("%s", log);
+		break;
+	}
 }
 
 bool DvbLinuxDevice::isReady() const
@@ -105,7 +109,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 	struct dvb_v5_fe_parms *parms = dvb_fe_open2(adapter, index, verbose, 0, dvbv5_log);
 
 	if (!parms) {
-		qInfo() << "DvbLinuxDevice::startDevice: cannot open frontend" << frontendPath;
+		qWarning("Cannot open frontend %s", qPrintable(frontendPath));
 		return;
 	}
 
@@ -136,7 +140,7 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 			transmissionTypes |= IsdbT;
 			break;
 		default: /* not supported yet */
-			qInfo() << "DvbLinuxDevice::startDevice: unsupported transmission type: " << parms->systems[i];
+			qWarning("Unsupported transmission type: %d", parms->systems[i]);
 			break;
 		}
 	}
@@ -161,10 +165,40 @@ void DvbLinuxDevice::startDevice(const QString &deviceId_)
 	if ((parms->info.caps & FE_CAN_GUARD_INTERVAL_AUTO) != 0) {
 		capabilities |= DvbTGuardIntervalAuto;
 	}
+
+	// Get the supported LNBf types if the device supports satellite
+	if (transmissionTypes & (DvbS | DvbS2)) {
+		for (int i = 0;; i++) {
+			const struct dvb_sat_lnb *lnb = dvb_sat_get_lnb(i);
+
+			if (!lnb)
+				break;
+
+			struct lnbSat lnbSat;
+
+			// FIXME: on newer libdvbv5, use dvb_sat_get_lnb_name() in
+			// order to get the name i18n translated
+			lnbSat.name = QString::fromUtf8(lnb->name);
+			lnbSat.alias = QString::fromUtf8(lnb->alias);
+			lnbSat.lowFreq = lnb->lowfreq;
+			lnbSat.highFreq = lnb->highfreq;
+			lnbSat.rangeSwitch = lnb->rangeswitch;
+			lnbSat.freqRange[0].low = lnb->freqrange[0].low;
+			lnbSat.freqRange[0].high = lnb->freqrange[0].high;
+			lnbSat.freqRange[1].low = lnb->freqrange[1].low;
+			lnbSat.freqRange[1].high = lnb->freqrange[1].high;
+
+			qDebug("supports lnb %s", lnb->alias);
+
+			lnbSatModels.append(lnbSat);
+		}
+	}
+
 	dvb_fe_close(parms);
 
-	qInfo() << "DvbLinuxDevice::startDevice: found dvb device" << deviceId << "/" << frontendName;
 	ready = true;
+
+	qInfo("Found dvb device %s: %s", qPrintable(deviceId), qPrintable(frontendName));
 }
 
 void DvbLinuxDevice::startCa()
@@ -244,14 +278,14 @@ bool DvbLinuxDevice::acquire()
 	dvbv5_parms = dvb_fe_open2(adapter, index, verbose, 0, dvbv5_log);
 
 	if (!dvbv5_parms) {
-		qInfo() << "DvbLinuxDevice::acquire: cannot open frontend" << frontendPath;
+		qWarning("Cannot open frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
 	dvrFd = open(QFile::encodeName(dvrPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dvrFd < 0) {
-		qInfo() << "DvbLinuxDevice::acquire: cannot open dvr" << dvrPath;
+		qWarning("Cannot open dvr %s", qPrintable(dvrPath));
 		dvb_fe_close(dvbv5_parms);
 		dvbv5_parms = NULL;
 		return false;
@@ -266,8 +300,7 @@ bool DvbLinuxDevice::setTone(SecTone tone)
 
 	if (dvb_fe_sec_tone(dvbv5_parms,
 		  (tone == ToneOn) ? SEC_TONE_ON : SEC_TONE_OFF) != 0) {
-		qInfo() << "DvbLinuxDevice::setTone: ioctl FE_SET_TONE failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_SET_TONE failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -279,8 +312,7 @@ bool DvbLinuxDevice::setVoltage(SecVoltage voltage)
 	Q_ASSERT(dvbv5_parms);
 
 	if (dvb_fe_lnb_high_voltage(dvbv5_parms, voltage == Voltage18V) != 0) {
-		qInfo() << "DvbLinuxDevice::setVoltage: ioctl FE_SET_VOLTAGE failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_SET_VOLTAGE failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -292,8 +324,7 @@ bool DvbLinuxDevice::sendMessage(const char *message, int length)
 	Q_ASSERT(dvbv5_parms && (length >= 0) && (length <= 6));
 
 	if (dvb_fe_diseqc_cmd(dvbv5_parms, length, (const unsigned char *)message) != 0) {
-		qInfo() << "DvbLinuxDevice::sendMessage: "
-		    "ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend" << frontendPath;
+		qWarning("ioctl FE_DISEQC_SEND_MASTER_CMD failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -305,8 +336,7 @@ bool DvbLinuxDevice::sendBurst(SecBurst burst)
 	Q_ASSERT(dvbv5_parms);
 
 	if (dvb_fe_diseqc_burst(dvbv5_parms, burst == BurstMiniB) != 0) {
-		qInfo() << "DvbLinuxDevice::sendBurst: ioctl FE_DISEQC_SEND_BURST failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_DISEQC_SEND_BURST failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -411,7 +441,7 @@ static fe_code_rate toDvbFecRate(DvbTransponderBase::FecRate fecRate)
 	case DvbTransponderBase::Fec1_3: return FEC_AUTO; // FIXME
 	case DvbTransponderBase::Fec1_4: return FEC_AUTO; // FIXME
 	case DvbTransponderBase::Fec2_3: return FEC_2_3;
-	case DvbTransponderBase::Fec2_5: return FEC_AUTO; // FIXME
+	case DvbTransponderBase::Fec2_5: return FEC_2_5;
 	case DvbTransponderBase::Fec3_4: return FEC_3_4;
 	case DvbTransponderBase::Fec3_5: return FEC_3_5;
 	case DvbTransponderBase::Fec4_5: return FEC_4_5;
@@ -583,6 +613,19 @@ static uint32_t toDvbInterleaving(IsdbTTransponder::Interleaving interleaving)
 	return (uint32_t)-1;
 }
 
+static uint32_t toDvbPolarization(DvbSTransponder::Polarization polarization)
+{
+	switch (polarization) {
+	case DvbSTransponder::Off:		return POLARIZATION_OFF;
+	case DvbSTransponder::Horizontal:	return POLARIZATION_H;
+	case DvbSTransponder::Vertical:		return POLARIZATION_V;
+	case DvbSTransponder::CircularLeft:	return POLARIZATION_L;
+	case DvbSTransponder::CircularRight:	return POLARIZATION_R;
+	}
+
+	return (uint32_t)-1;
+}
+
 static fe_hierarchy toDvbHierarchy(DvbTTransponder::Hierarchy hierarchy)
 {
 	switch (hierarchy) {
@@ -693,7 +736,7 @@ static DvbTransponderBase::FecRate DvbtoFecRate(uint32_t fecRate)
 //	case FEC_AUTO: return DvbTransponderBase::Fec1_3; // FIXME
 //	case FEC_AUTO: return DvbTransponderBase::Fec1_4; // FIXME
 	case FEC_2_3:  return DvbTransponderBase::Fec2_3;
-//	case FEC_AUTO: return DvbTransponderBase::Fec2_5; // FIXME
+	case FEC_2_5:  return DvbTransponderBase::Fec2_5;
 	case FEC_3_4:  return DvbTransponderBase::Fec3_4;
 	case FEC_3_5:  return DvbTransponderBase::Fec3_5;
 	case FEC_4_5:  return DvbTransponderBase::Fec4_5;
@@ -861,13 +904,34 @@ static DvbT2Transponder::Hierarchy DvbT2toHierarchy(uint32_t hierarchy)
 	}
 }
 
+bool DvbLinuxDevice::satSetup(QString lnbModel, int satNumber, int bpf)
+{
+	Q_ASSERT(dvbv5_parms);
+
+	int lnb = dvb_sat_search_lnb(lnbModel.toUtf8());
+	dvbv5_parms->lnb = dvb_sat_get_lnb(lnb);
+	if (!dvbv5_parms->lnb) {
+		qCritical("Cannot set LNBf type to %s", qPrintable(lnbModel));
+		return false;
+	}
+
+	qDebug("Using LNBf type %s", qPrintable(lnbModel));
+
+	dvbv5_parms->sat_number = satNumber;
+	dvbv5_parms->freq_bpf = bpf;
+
+	return true;
+}
+
 bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 {
 	Q_ASSERT(dvbv5_parms);
 	stopDvr();
 	fe_delivery_system_t delsys;
 
-	qInfo() << "tune to:" << transponder.toString();
+	qDebug("tune to: %s", qPrintable(transponder.toString()));
+
+	// FIXME: add support for LNA on/off
 
 	switch (transponder.getTransmissionType()) {
 	case DvbTransponderBase::DvbS: {
@@ -876,11 +940,15 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		delsys = SYS_DVBS;
 		dvb_set_sys(dvbv5_parms, delsys);
 
+		dvb_fe_store_parm(dvbv5_parms, DTV_POLARIZATION, toDvbPolarization(dvbSTransponder->polarization));
 		dvb_fe_store_parm(dvbv5_parms, DTV_FREQUENCY, dvbSTransponder->frequency);
 		dvb_fe_store_parm(dvbv5_parms, DTV_INVERSION, INVERSION_AUTO);
 		dvb_fe_store_parm(dvbv5_parms, DTV_SYMBOL_RATE, dvbSTransponder->symbolRate);
 		dvb_fe_store_parm(dvbv5_parms, DTV_INNER_FEC, toDvbFecRate(dvbSTransponder->fecRate));
 		freqMHz = dvbSTransponder->frequency / 1000.;
+
+		/// FIXME
+
 		break;
 	    }
 	case DvbTransponderBase::DvbS2: {
@@ -889,6 +957,7 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		delsys = SYS_DVBS2;
 		dvb_set_sys(dvbv5_parms, delsys);
 
+		dvb_fe_store_parm(dvbv5_parms, DTV_POLARIZATION, toDvbPolarization(dvbS2Transponder->polarization));
 		dvb_fe_store_parm(dvbv5_parms, DTV_FREQUENCY, dvbS2Transponder->frequency);
 		dvb_fe_store_parm(dvbv5_parms, DTV_INVERSION, INVERSION_AUTO);
 		dvb_fe_store_parm(dvbv5_parms, DTV_SYMBOL_RATE, dvbS2Transponder->symbolRate);
@@ -1016,17 +1085,15 @@ bool DvbLinuxDevice::tune(const DvbTransponder &transponder)
 		break;
 	    }
 	case DvbTransponderBase::Invalid:
-		qInfo() << "DvbLinuxDevice::getProps: unknown transmission type";
+		qWarning("Invalid transmission type");
 		return false;
 	default:
-		qInfo() << "DvbLinuxDevice::tune: unknown transmission type" <<
-			transponder.getTransmissionType();
+		qWarning("Unknown transmission type %d", transponder.getTransmissionType());
 		return false;
 	}
 
 	if (dvb_fe_set_parms(dvbv5_parms) != 0) {
-		qInfo() << "DvbLinuxDevice::tune: ioctl FE_SET_PROPERTY failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_SET_PROPERTY failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1201,11 +1268,10 @@ bool DvbLinuxDevice::getProps(DvbTransponder &transponder)
 		break;
 	    }
 	case DvbTransponderBase::Invalid:
-		qInfo() << "DvbLinuxDevice::getProps: unknown transmission type";
+		qWarning("Invalid transmission type");
 		return false;
 	default:
-		qInfo() << "DvbLinuxDevice::getProps: unknown transmission type" <<
-			transponder.getTransmissionType();
+		qWarning("Unknown transmission type %s", qPrintable(transponder.getTransmissionType()));
 		return false;
 	}
 	return true;
@@ -1230,29 +1296,28 @@ bool DvbLinuxDevice::isTuned()
 	uint32_t status = 0;
 
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qInfo() << "DvbLinuxDevice::isTuned: ioctl FE_READ_STATUS failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
 	if (dvb_fe_retrieve_stats(dvbv5_parms, DTV_STATUS, &status) != 0) {
-		qInfo() << "DvbLinuxDevice::isTuned: ioctl FE_READ_STATUS failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
 	return ((status & FE_HAS_LOCK) != 0);
 }
 
-int DvbLinuxDevice::getSignal()
+float DvbLinuxDevice::getSignal(Scale &scale)
 {
 	Q_ASSERT(dvbv5_parms);
 	struct dtv_stats *stat;
-	int signal;
+	float signal;
+
+	scale = DvbBackendDevice::NotSupported;
 
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qInfo() << "DvbLinuxDevice::isTuned: ioctl FE_READ_STATUS failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1262,34 +1327,40 @@ int DvbLinuxDevice::getSignal()
 
 	switch (stat->scale) {
 	case FE_SCALE_RELATIVE:
-		signal = (100 * stat->uvalue) / 65535;
+		signal = (100. * stat->uvalue) / 65535;
+
+		scale = DvbBackendDevice::Percentage;
+
+		// Assert that signal will be within the expected range
+		if (signal > 100.)
+			signal = 100.;
+		else if (signal < 0)
+			signal = 0;
+
 		break;
 	case FE_SCALE_DECIBEL:
 		// Convert to dBuV @ 75 ohms, to be positive and typically smaller than 100
-		signal = (108800 + stat->svalue) / 1000;
+		signal = (108800. + stat->svalue) / 1000;
+
+		scale = DvbBackendDevice::dBuV;
+
 		break;
 	default:
 		return -1;
 	}
 
-	// Assert that signal will be within the expected range
-	if (signal > 100)
-		signal = 100;
-	else if (signal < 0)
-		signal = 0;
-
 	return signal;
 }
 
-int DvbLinuxDevice::getSnr()
+float DvbLinuxDevice::getSnr(Scale &scale)
 {
 	Q_ASSERT(dvbv5_parms);
 	struct dtv_stats *stat;
-	int cnr;
+	float cnr;
 
+	scale = DvbBackendDevice::NotSupported;
 	if (dvb_fe_get_stats(dvbv5_parms) != 0) {
-		qInfo() << "DvbLinuxDevice::isTuned: ioctl FE_READ_STATUS failed for frontend" <<
-			frontendPath;
+		qWarning("ioctl FE_READ_STATUS failed for frontend %s", qPrintable(frontendPath));
 		return false;
 	}
 
@@ -1299,19 +1370,26 @@ int DvbLinuxDevice::getSnr()
 
 	switch (stat->scale) {
 	case FE_SCALE_RELATIVE:
-		cnr = (100 * stat->uvalue) / 65535;
+		cnr = (100. * stat->uvalue) / 65535;
+
+		// Assert that CNR will be within the expected range
+		if (cnr > 100.)
+			cnr = 100.;
+		else if (cnr < 0.)
+			cnr = 0.;
+
+		scale = DvbBackendDevice::Percentage;
+
 		break;
 	case FE_SCALE_DECIBEL:
-		cnr = (stat->svalue / 1000);
+		cnr = (stat->svalue / 1000.);
+
+		scale = DvbBackendDevice::Decibel;
+
 		break;
 	default:
 		return -1;
 	}
-	// Assert that CNR will be within the expected range
-	if (cnr > 100)
-		cnr = 100;
-	else if (cnr < 0)
-		cnr = 0;
 
 	return cnr;
 }
@@ -1321,14 +1399,14 @@ bool DvbLinuxDevice::addPidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (dmxFds.contains(pid)) {
-		qInfo() << "DvbLinuxDevice::addPidFilter: pid filter already set up for pid" << pid;
+		qWarning("PID filter already set up for pid %d", pid);
 		return false;
 	}
 
 	int dmxFd = open(QFile::encodeName(demuxPath).constData(), O_RDONLY | O_NONBLOCK | O_CLOEXEC);
 
 	if (dmxFd < 0) {
-		qInfo() << "DvbLinuxDevice::addPidFilter: cannot open demux" << demuxPath;
+		qWarning("Cannot open demux %s", qPrintable(demuxPath));
 		return false;
 	}
 
@@ -1341,8 +1419,7 @@ bool DvbLinuxDevice::addPidFilter(int pid)
 	pes_filter.flags = DMX_IMMEDIATE_START;
 
 	if (ioctl(dmxFd, DMX_SET_PES_FILTER, &pes_filter) != 0) {
-		qInfo() << "DvbLinuxDevice::addPidFilter: cannot set up pid filter for demux" <<
-			demuxPath;
+		qWarning("Cannot set up PID filter for demux %s", qPrintable(demuxPath));
 		close(dmxFd);
 		return false;
 	}
@@ -1356,7 +1433,7 @@ void DvbLinuxDevice::removePidFilter(int pid)
 	Q_ASSERT(frontendFd >= 0);
 
 	if (!dmxFds.contains(pid)) {
-		qInfo() << "DvbLinuxDevice::removePidFilter: no pid filter set up for pid" << pid;
+		qWarning("No PID filter set up for PID %i", pid);
 		return;
 	}
 
@@ -1421,7 +1498,7 @@ void DvbLinuxDevice::startDvr()
 		}
 
 		if ((dvrPipe[0] < 0) || (dvrPipe[1] < 0)) {
-			qInfo() << "DvbLinuxDevice::startDvr: cannot create pipe";
+			qCritical("Cannot create pipe");
 			return;
 		}
 	}
@@ -1454,7 +1531,7 @@ void DvbLinuxDevice::startDvr()
 					continue;
 				}
 
-				qInfo() << "DvbLinuxDevice::startDvr: cannot read from dvr" << dvrPath << errno;
+				qWarning("Cannot read from dvr %s: error: %d", qPrintable(dvrPath), errno);
 				return;
 			}
 		}
@@ -1473,14 +1550,14 @@ void DvbLinuxDevice::stopDvr()
 		Q_ASSERT((dvrPipe[0] >= 0) && (dvrPipe[1] >= 0));
 
 		if (write(dvrPipe[1], " ", 1) != 1) {
-			qInfo() << "DvbLinuxDevice::stopDvr: cannot write to pipe";
+			qWarning("Cannot write to pipe");
 		}
 
 		wait();
 		char data;
 
 		if (read(dvrPipe[0], &data, 1) != 1) {
-			qInfo() << "DvbLinuxDevice::stopDvr: cannot read from pipe";
+			qWarning("Cannot read from pipe");
 		}
 	}
 }
@@ -1501,7 +1578,7 @@ void DvbLinuxDevice::run()
 				continue;
 			}
 
-			qInfo() << "DvbLinuxDevice::run: poll failed";
+			qWarning("Poll failed with error: %d", errno);
 			return;
 		}
 
@@ -1522,7 +1599,7 @@ void DvbLinuxDevice::run()
 					continue;
 				}
 
-				qInfo() << "DvbLinuxDevice::run: cannot read from dvr" << dvrPath << errno;
+				qWarning("Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
 				dataSize = int(read(dvrFd, dvrBuffer.data, bufferSize));
 
 				if (dataSize < 0) {
@@ -1534,8 +1611,7 @@ void DvbLinuxDevice::run()
 						continue;
 					}
 
-					qInfo() << "DvbLinuxDevice::run: cannot read from dvr" <<
-						dvrPath << errno;
+					qWarning("Cannot read from dvr %s: error %d", qPrintable(dvrPath), errno);
 					return;
 				}
 			}
@@ -1720,6 +1796,8 @@ DvbLinuxDeviceManager::DvbLinuxDeviceManager(QObject *parent) : QObject(parent)
 		return;
 	}
 	close(fd);
+	qInfo("Starting DvbDeviceMonitor thread");
+
 	monitor = new DvbDeviceMonitor(this);
 	monitor->start();
 }
@@ -1802,14 +1880,12 @@ void DvbLinuxDeviceManager::componentAdded(const QString &udi)
 	QString devicePath = QString(QLatin1String("/dev/dvb/adapter%1/%2%3")).arg(adapter).arg(type).arg(index);
 
 	if ((adapter < 0) || (adapter > 0x7fff) || (index < 0) || (index > 0x7fff)) {
-		qInfo() << "DvbLinuxDeviceManager::componentAdded: "
-		    "cannot determine adapter or index for device" << udi;
+		qWarning("Cannot determine adapter or index for device %s", qPrintable(udi));
 		return;
 	}
 
 	if (devicePath.isEmpty()) {
-		qInfo() << "DvbLinuxDeviceManager::componentAdded: cannot determine path for device" <<
-			udi;
+		qWarning("Cannot determine path for device %s", qPrintable(udi));
 		return;
 	}
 
@@ -1935,7 +2011,8 @@ void DvbLinuxDeviceManager::componentRemoved(const QString &udi)
 
 	bool removeDevice = false;
 
-	qInfo() << "Digital TV device removed: " << udi;
+	if (device->isReady())
+		qInfo("Digital TV device removed %s: %s", qPrintable(device->getDeviceId()), qPrintable(device->getFrontendName()));
 
 	if (udi == device->caUdi) {
 		device->caPath.clear();
