@@ -44,6 +44,8 @@ public:
 	void stopCa();
 	void stopDevice();
 	void enableDvbDump();
+	QString getDeviceId();
+	QString getFrontendName();
 
 	QString caPath;
 	QString caUdi;
@@ -58,8 +60,6 @@ public:
 	QString frontendUdi;
 
 protected:
-	QString getDeviceId();
-	QString getFrontendName();
 	TransmissionTypes getTransmissionTypes();
 	Capabilities getCapabilities();
 	void setFrontendDevice(DvbFrontendDevice *frontend_);
@@ -69,12 +69,13 @@ protected:
 	bool setVoltage(SecVoltage voltage);
 	bool sendMessage(const char *message, int length);
 	bool sendBurst(SecBurst burst);
+	bool satSetup(QString lnbModel, int satNumber, int bpf);
 	bool tune(const DvbTransponder &transponder); // discards obsolete data
 	bool getProps(DvbTransponder &transponder);
 	bool isTuned();
 	float getFrqMHz();
-	int getSignal(); // 0 - 100 [%] or -1 = not supported
-	int getSnr(); // 0 - 100 [%] or -1 = not supported
+	float getSignal(Scale &scale);
+	float getSnr(DvbBackendDevice::Scale &scale);
 	bool addPidFilter(int pid);
 	void removePidFilter(int pid);
 	void startDescrambling(const QByteArray &pmtSectionData);
