@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -273,7 +274,7 @@ QString DvbManager::getAutoScanSource(const QString &source) const
 	QPair<TransmissionType, QString> scanSource = sourceMapping.value(source);
 
 	if (scanSource.second.isEmpty()) {
-		qInfo() << "DvbManager::getAutoScanSource: invalid source";
+		qWarning("Invalid source for autoscan");
 		return QString();
 	}
 
@@ -293,7 +294,7 @@ QList<DvbTransponder> DvbManager::getTransponders(DvbDevice *device, const QStri
 	QPair<TransmissionType, QString> scanSource = sourceMapping.value(source);
 
 	if (scanSource.second.isEmpty()) {
-		qInfo() << "DvbManager::getTransponders: invalid source";
+		qWarning("Invalid source. Can't get transponder");
 		return QList<DvbTransponder>();
 	}
 
@@ -315,19 +316,19 @@ bool DvbManager::updateScanData(const QByteArray &data)
 	QByteArray uncompressed = qUncompress(data);
 
 	if (uncompressed.isEmpty()) {
-		qInfo() << "DvbManager::updateScanData: qUncompress failed";
+		qWarning("Failed to uncompress the scan data file");
 		return false;
 	}
 
 	if (!DvbScanData(uncompressed).readDate().isValid()) {
-		qInfo() << "DvbManager::updateScanData: invalid format";
+		qWarning("Invalid format at the scan data file");
 		return false;
 	}
 
 	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/scanfile.dvb"));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		qInfo() << "DvbManager::updateScanData: cannot open" << file.fileName();
+		qWarning("Cannot open %s", qPrintable(file.fileName()));
 		return false;
 	}
 
@@ -499,26 +500,6 @@ void DvbManager::setCreateInfoFile(bool createInfoFile)
 	KSharedConfig::openConfig()->group("DVB").writeEntry("CreateInfoFile", createInfoFile);
 }
 
-double DvbManager::getLatitude()
-{
-	return KSharedConfig::openConfig()->group("DVB").readEntry("Latitude", 0.0);
-}
-
-double DvbManager::getLongitude()
-{
-	return KSharedConfig::openConfig()->group("DVB").readEntry("Longitude", 0.0);
-}
-
-void DvbManager::setLatitude(double value)
-{
-	KSharedConfig::openConfig()->group("DVB").writeEntry("Latitude", value);
-}
-
-void DvbManager::setLongitude(double value)
-{
-	KSharedConfig::openConfig()->group("DVB").writeEntry("Longitude", value);
-}
-
 void DvbManager::enableDvbDump()
 {
 	if (dvbDumpEnabled) {
@@ -600,12 +581,11 @@ void DvbManager::loadDeviceManager()
 		QObject *deviceManager = QPluginLoader(path).instance();
 
 		if (deviceManager == NULL) {
-			qInfo() << "DvbManager::loadDeviceManager: cannot load dvb device manager" <<
-				path;
+			qWarning("Cannot load dvb device manager %s", qPrintable(path));
 			break;
 		}
 
-		qInfo() << "DvbManager::loadDeviceManager: using dvb device manager" << path;
+		qInfo("Using dvb device manager %s", qPrintable(path));
 		deviceManager->setParent(this);
 		connect(deviceManager, SIGNAL(requestBuiltinDeviceManager(QObject*&)),
 			this, SLOT(requestBuiltinDeviceManager(QObject*&)));
@@ -617,7 +597,7 @@ void DvbManager::loadDeviceManager()
 		return;
 	}
 
-	qInfo() << "DvbManager::loadDeviceManager: using built-in dvb device manager";
+	qInfo("Using built-in dvb device manager");
 	DvbLinuxDeviceManager *deviceManager = new DvbLinuxDeviceManager(this);
 	connect(deviceManager, SIGNAL(deviceAdded(DvbBackendDevice*)),
 		this, SLOT(deviceAdded(DvbBackendDevice*)));
@@ -631,7 +611,7 @@ void DvbManager::readDeviceConfigs()
 	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/config.dvb"));
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		qInfo() << "DvbManager::readDeviceConfigs: cannot open" << file.fileName();
+		qWarning("Cannot open %s", qPrintable(file.fileName()));
 		return;
 	}
 
@@ -673,12 +653,14 @@ void DvbManager::readDeviceConfigs()
 			config->timeout = reader.readInt(QLatin1String("timeout"));
 
 			if (type == DvbConfigBase::DvbS) {
+				config->latitude = 0;
+				config->longitude = 0;
 				config->configuration = reader.readEnum(QLatin1String("configuration"),
 					DvbConfigBase::ConfigurationMax);
 				config->lnbNumber = reader.readInt(QLatin1String("lnbNumber"));
-				config->lowBandFrequency = reader.readInt(QLatin1String("lowBandFrequency"));
-				config->switchFrequency = reader.readInt(QLatin1String("switchFrequency"));
-				config->highBandFrequency = reader.readInt(QLatin1String("highBandFrequency"));
+				config->currentLnb.alias = reader.readString(QLatin1String("lnb"));
+				config->latitude = reader.readDouble(QLatin1String("latitude"));
+				config->longitude = reader.readInt(QLatin1String("longitude"));
 			}
 
 			if (!reader.isValid()) {
@@ -692,9 +674,8 @@ void DvbManager::readDeviceConfigs()
 		deviceConfigs.append(deviceConfig);
 	}
 
-	if (!reader.isValid()) {
-		qInfo() << "DvbManager::readDeviceConfigs: cannot read" << file.fileName();
-	}
+	if (!reader.isValid())
+		qWarning("Cannot read %s", qPrintable(file.fileName()));
 }
 
 void DvbManager::writeDeviceConfigs()
@@ -702,7 +683,7 @@ void DvbManager::writeDeviceConfigs()
 	QFile file(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/config.dvb"));
 
 	if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
-		qInfo() << "DvbManager::writeDeviceConfigs: cannot open" << file.fileName();
+		qWarning("Cannot open %s", qPrintable(file.fileName()));
 		return;
 	}
 
@@ -725,9 +706,9 @@ void DvbManager::writeDeviceConfigs()
 			if (config->getTransmissionType() == DvbConfigBase::DvbS) {
 				writer.write(QLatin1String("configuration"), config->configuration);
 				writer.write(QLatin1String("lnbNumber"), config->lnbNumber);
-				writer.write(QLatin1String("lowBandFrequency"), config->lowBandFrequency);
-				writer.write(QLatin1String("switchFrequency"), config->switchFrequency);
-				writer.write(QLatin1String("highBandFrequency"), config->highBandFrequency);
+				writer.write(QLatin1String("lnb"), config->currentLnb.alias);
+				writer.write(QLatin1String("latitude"), config->latitude);
+				writer.write(QLatin1String("longitude"), config->longitude);
 			}
 		}
 	}
@@ -782,12 +763,12 @@ void DvbManager::readScanData()
 		globalDate = DvbScanData(globalFile.read(1024)).readDate();
 
 		if (globalDate.isNull()) {
-			qInfo() << "DvbManager::readScanData: cannot parse" << globalFile.fileName();
+			qWarning("Cannot parse %s", qPrintable(globalFile.fileName()));
 		}
 
 		globalFile.close();
 	} else {
-		qInfo() << "DvbManager::readScanData: cannot open global scanfile " << globalFile.fileName();
+		qWarning("Cannot open global scanfile %s", qPrintable(globalFile.fileName()));
 	}
 
 	QFile localFile(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/scanfile.dvb"));
@@ -799,7 +780,7 @@ void DvbManager::readScanData()
 		localDate = DvbScanData(localData).readDate();
 
 		if (localDate.isNull()) {
-			qInfo() << "DvbManager::readScanData: cannot parse" << localFile.fileName();
+			qWarning("Cannot parse %s", qPrintable(localFile.fileName()));
 		}
 
 		localFile.close();
@@ -809,19 +790,18 @@ void DvbManager::readScanData()
 		localData.clear();
 
 		if (localFile.exists() && !localFile.remove()) {
-			qInfo() << "DvbManager::readScanData: cannot remove" << localFile.fileName();
+			qWarning("Cannot remove %s", qPrintable(localFile.fileName()));
 		}
 
 		if (!globalFile.copy(localFile.fileName())) {
-			qInfo() << "DvbManager::readScanData: cannot copy" << globalFile.fileName() <<
-				QLatin1String("to") << localFile.fileName();
+			qWarning("Cannot copy %s to %s", qPrintable(globalFile.fileName()), qPrintable(localFile.fileName()));
 		}
 
 		if (localFile.open(QIODevice::ReadOnly)) {
 			localData = localFile.readAll();
 			localFile.close();
 		} else {
-			qInfo() << "DvbManager::readScanData: cannot open" << localFile.fileName();
+			qWarning("Cannot open %s", qPrintable(localFile.fileName()));
 			scanDataDate = QDate(1900, 1, 1);
 			return;
 		}
@@ -831,7 +811,7 @@ void DvbManager::readScanData()
 	scanDataDate = data.readDate();
 
 	if (!scanDataDate.isValid()) {
-		qInfo() << "DvbManager::readScanData: cannot parse" << localFile.fileName();
+		qWarning("Cannot parse %s", qPrintable(localFile.fileName()));
 		scanDataDate = QDate(1900, 1, 1);
 		return;
 	}
@@ -841,9 +821,6 @@ void DvbManager::readScanData()
 	QRegularExpression rejex = QRegularExpression("\\[(\\S+)/(\\S+)\\]");
 	QRegularExpressionMatch match;
 	TransmissionType type;
-	QString errMsg = "DvbManager::readScanData: ";
-
-	errMsg.append(localFile.fileName()).append(": ");
 
 	while (!data.checkEnd()) {
 		const char *line = data.readLine();
@@ -855,7 +832,7 @@ void DvbManager::readScanData()
 		QString qLine(line);
 
 		if (!qLine.contains(rejex, &match)) {
-			qInfo() << "unrecognized line: " << line;
+			qWarning("Unrecognized line: '%s'", line);
 			continue;
 
 		}
@@ -874,8 +851,7 @@ void DvbManager::readScanData()
 		else if (!typeStr.compare("isdb-t", Qt::CaseInsensitive))
 			type = IsdbT;
 		else {
-			qInfo() << errMsg << "transmission type "
-				<< typeStr << "unknown";
+			qWarning("Transmission type '%s' unknown", qPrintable(typeStr));
 			continue;
 		}
 
@@ -900,8 +876,7 @@ void DvbManager::readScanData()
 				DvbTransponder::fromString(QString::fromLatin1(line));
 
 			if (!transponder.isValid()) {
-				qInfo() << errMsg
-					<< "error parsing line: '" << line << "'";
+				qWarning("Error parsing line : '%s'", qPrintable(line));
 			} else {
 				transponders.append(transponder);
 
@@ -955,7 +930,7 @@ void DvbManager::readScanData()
 	}
 
 	if (!data.checkEnd())
-		qInfo() << errMsg << "some data were not parsed";
+		qWarning("Some data at the scan file were not parsed");
 }
 
 DvbDeviceConfig::DvbDeviceConfig(const QString &deviceId_, const QString &frontendName_,
