@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -80,7 +81,7 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 	}
 
 	if (!file.open(QIODevice::ReadOnly)) {
-		qInfo() << "DvbRecordingModel::DvbRecordingModel: cannot open file" << file.fileName();
+		qWarning("Cannot open file %s", qPrintable(file.fileName()));
 		return;
 	}
 
@@ -118,8 +119,7 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 		stream >> recording.details;
 
 		if (stream.status() != QDataStream::Ok) {
-			qInfo() << "DvbRecordingModel::DvbRecordingModel: invalid recordings in file" <<
-				file.fileName();
+			qWarning("Invalid recordings in file %s", qPrintable(file.fileName()));
 			break;
 		}
 
@@ -127,14 +127,14 @@ DvbRecordingModel::DvbRecordingModel(DvbManager *manager_, QObject *parent) : QO
 	}
 
 	if (!file.remove()) {
-		qInfo() << "DvbRecordingModel::DvbRecordingModel: cannot remove file" << file.fileName();
+		qWarning("Cannot remove file %s", qPrintable(file.fileName()));
 	}
 }
 
 DvbRecordingModel::~DvbRecordingModel()
 {
 	if (hasPendingOperation) {
-		qInfo() << "DvbRecordingModel::~DvbRecordingModel: illegal recursive call";
+		qWarning("Illegal recursive call");
 	}
 
 	sqlFlush();
@@ -179,7 +179,7 @@ DvbSharedRecording DvbRecordingModel::addRecording(DvbRecording &recording, bool
 {
 	if (checkForRecursion) {
 		if (hasPendingOperation) {
-			qInfo() << "DvbRecordingModel::addRecording: illegal recursive call";
+			qWarning("Illegal recursive call");
 			return DvbSharedRecording();
 		}
 
@@ -187,7 +187,7 @@ DvbSharedRecording DvbRecordingModel::addRecording(DvbRecording &recording, bool
 	}
 
 	if (!recording.validate()) {
-		qInfo() << "DvbRecordingModel::addRecording: invalid recording";
+		qWarning("Invalid recording");
 		return DvbSharedRecording();
 	}
 
@@ -208,7 +208,7 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 	DvbRecording &modifiedRecording)
 {
 	if (hasPendingOperation) {
-		qInfo() << "DvbRecordingModel::updateRecording: illegal recursive call";
+		qWarning("Illegal recursive call");
 		return;
 	}
 
@@ -216,7 +216,7 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 
 	if (!recording.isValid() || (recordings.value(*recording) != recording) ||
 	    !modifiedRecording.validate()) {
-		qInfo() << "DvbRecordingModel::updateRecording: invalid recording";
+		qWarning("Invalid recording");
 		return;
 	}
 
@@ -239,14 +239,14 @@ void DvbRecordingModel::updateRecording(DvbSharedRecording recording,
 void DvbRecordingModel::removeRecording(DvbSharedRecording recording)
 {
 	if (hasPendingOperation) {
-		qInfo() << "DvbRecordingModel::removeRecording: illegal recursive call";
+		qWarning("Illegal recursive call");
 		return;
 	}
 
 	EnsureNoPendingOperation ensureNoPendingOperation(hasPendingOperation);
 
 	if (!recording.isValid() || (recordings.value(*recording) != recording)) {
-		qInfo() << "DvbRecordingModel::removeRecording: invalid recording";
+		qWarning("Invalid recording");
 		return;
 	}
 
@@ -266,19 +266,19 @@ void DvbRecordingModel::disableLessImportant(DvbSharedRecording &recording1, Dvb
 	if (recording1->priority < recording2->priority) {
 		DvbRecording rec1 = *(recording1.constData());
 		rec1.disabled = true;
-		qInfo() << "DvbRecordingModel::disableLessImportant disabled" << recording1->name;
+		qWarning("Disabled %s because %s has more priority", qPrintable(recording1->name), qPrintable(recording2->name));
 	}
 	if (recording2->priority < recording1->priority) {
 		DvbRecording rec2 = *(recording1.constData());
 		rec2.disabled = true;
-		qInfo() << "DvbRecordingModel::disableLessImportant disabled" << recording2->name;
+		qWarning("Disabled %s because %s has more priority", qPrintable(recording2->name), qPrintable(recording1->name));
 	}
 }
 
 void DvbRecordingModel::addToUnwantedRecordings(DvbSharedRecording recording)
 {
 	unwantedRecordings.append(recording);
-	qInfo() << "DvbRecordingModel::addToUnwantedRecordings executed" << recording->name;
+	qDebug("executed %s", qPrintable(recording->name));
 }
 
 void DvbRecordingModel::executeActionAfterRecording(DvbRecording recording)
@@ -290,9 +290,9 @@ void DvbRecordingModel::executeActionAfterRecording(DvbRecording recording)
 	{
 		QProcess* child = new QProcess();
 		child->start(stopCommand);
-		qInfo() << "DvbRecordingModel::shutdownWhenEmpty:could not execute cmd";
+		qWarning("Not executing command after recording");
 	}
-	qInfo() << "DvbRecordingModel::executeActionAfterRecording executed.";
+	qDebug("executed.");
 
 
 }
@@ -325,7 +325,7 @@ void DvbRecordingModel::removeDuplicates()
 					&& loopEntry1.name == loopEntry2.name) {
 					recordings.remove(recordings.key(rec1));
 					recordingMap.remove(rec1);
-					qInfo() << "DvbRecordingModel::removeDuplicates removed." << loopEntry1.name;
+					qDebug("Removed. %s", qPrintable(loopEntry1.name));
 				}
 			}
 			j = j + 1;
@@ -334,7 +334,7 @@ void DvbRecordingModel::removeDuplicates()
 	}
 	epgModel->setRecordings(recordingMap);
 
-	qInfo() << "DvbRecordingModel::removeDuplicates executed.";
+	qDebug("executed.");
 
 }
 
@@ -379,7 +379,7 @@ bool DvbRecordingModel::existsSimilarRecording(DvbEpgEntry recording)
 				&& QString::compare(entry.channel->name, loopEntry.channel->name) == 0
 				&& QString::compare((entry.duration).toString(),
 						loopEntry.duration.addSecs(- manager->getBeginMargin() - manager->getEndMargin()).toString()) == 0) {
-			qInfo() << "DvbRecordingModel::existsSimilarRecording Found from unwanteds " << loopEntry.name;
+			qDebug("Found from unwanteds %s", qPrintable(loopEntry.name));
 			found = true;
 			break;
 		}
@@ -413,8 +413,7 @@ void DvbRecordingModel::disableConflicts()
 		{
 			if (isInConflictWithAll(rec2, conflictList)) {
 				conflictList.append(rec2);
-				qInfo() << "DvbRecordingModel::disableConflicts:" << rec1->name << rec1->begin.toString() <<
-						" and " << rec2->name << rec2->begin.toString();
+				qDebug("conflict: '%s' '%s' and '%s' '%s'", qPrintable(rec1->name), qPrintable(rec1->begin.toString()), qPrintable(rec2->name), qPrintable(rec2->begin.toString()));
 
 			}
 
@@ -478,13 +477,13 @@ DvbSharedRecording DvbRecordingModel::getLeastImportant(QList<DvbSharedRecording
 	DvbSharedRecording leastImportant = recList.value(0);
 	foreach(DvbSharedRecording listRec, recList)
 	{
-		qInfo() << "DvbRecordingModel::getLeastImportant: name and priority" << listRec->name << listRec->priority;
+		qDebug("name and priority %s %s", qPrintable(listRec->name), qPrintable(listRec->priority));
 		if (listRec->priority < leastImportant->priority) {
 			leastImportant = listRec;
 		}
 	}
 
-	qInfo() << "DvbRecordingModel::getLeastImportant:" << leastImportant->name;
+	qDebug("least important: %s", qPrintable(leastImportant->name));
 	return leastImportant;
 }
 
@@ -501,7 +500,7 @@ void DvbRecordingModel::disableLeastImportants(QList<DvbSharedRecording> recList
 			if (listRecShared->priority == leastImportance) {
 				listRec.disabled = true;
 				updateRecording(listRecShared, listRec);
-				qInfo() << "DvbRecordingModel::disableLeastImportants disabled:" << listRec.name << listRec.begin.toString();
+				qDebug("disabled: %s %s", qPrintable(listRec.name), qPrintable(listRec.begin.toString()));
 			}
 		}
 	}
@@ -533,7 +532,7 @@ void DvbRecordingModel::findNewRecordings()
 					int priority = manager->getRecordingRegexPriorityList().value(i);
 					epgModel->scheduleProgram(epgMap.value(key), manager->getBeginMargin(),
 							manager->getEndMargin(), false, priority);
-					qInfo() << "DvbRecordingModel::findNewRecordings: scheduled" << title;
+					qDebug("scheduled %s", qPrintable(title));
 					}
 				}
 			}
@@ -541,7 +540,7 @@ void DvbRecordingModel::findNewRecordings()
 		}
 	}
 
-	qInfo() << "DvbRecordingModel::findNewRecordings executed.";
+	qDebug("executed.");
 }
 
 void DvbRecordingModel::timerEvent(QTimerEvent *event)
@@ -570,7 +569,7 @@ void DvbRecordingModel::bindToSqlQuery(SqlKey sqlKey, QSqlQuery &query, int inde
 	DvbSharedRecording recording = recordings.value(sqlKey);
 
 	if (!recording.isValid()) {
-		qInfo() << "DvbRecordingModel::bindToSqlQuery: invalid recording";
+		qWarning("Invalid recording");
 		return;
 	}
 
@@ -633,7 +632,7 @@ int DvbRecordingModel::getSecondsUntilNextRecording() const
 		}
 		if (end > QDateTime::currentDateTime().toUTC() && rec.begin <= QDateTime::currentDateTime().toUTC()) {
 			timeUntil = 0;
-			qInfo() << "DvbRecordingModel::getSecondsUntilNextRecording: rec ongoing" << rec.name;
+			qDebug("Rec ongoing %s", qPrintable(rec.name));
 			break;
 		}
 		if (rec.begin > QDateTime::currentDateTime().toUTC()) {
@@ -644,7 +643,7 @@ int DvbRecordingModel::getSecondsUntilNextRecording() const
 
 	}
 
-	qInfo() << "DvbRecordingModel::getSecondsUntilNextRecording: returned TRUE" << QString::number(timeUntil);
+	qDebug("returned TRUE %ld", timeUntil);
 	return timeUntil;
 }
 
@@ -660,8 +659,8 @@ bool DvbRecordingModel::shouldWeScanChannels() const
 	if (idleTime > 1000 * 3600) {
 		if (DvbRecordingModel::getSecondsUntilNextRecording() > numberOfChannels * 10) {
 			if (DvbRecordingModel::isScanWhenIdle()) {
+				qDebug("Scan on Idle enabled");
 				return true;
-				qInfo() << "DvbRecordingModel::shouldWeScanChannels: returned TRUE";
 			}
 		}
 	}
@@ -671,33 +670,35 @@ bool DvbRecordingModel::shouldWeScanChannels() const
 
 void delay(int seconds)
 {
-    QTime dieTime= QTime::currentTime().addSecs(seconds);
-    while (QTime::currentTime() < dieTime)
-        QCoreApplication::processEvents(QEventLoop::AllEvents, 100);
-	qInfo() << "DvbRecordingModel::delay: Delayed for " << QString::number(seconds) << " seconds";
+	QTime dieTime= QTime::currentTime().addSecs(seconds);
+	while (QTime::currentTime() < dieTime)
+		QCoreApplication::processEvents(QEventLoop::AllEvents, 100);
+
+	qInfo("Delayed for %d seconds", seconds);
 }
 
 void DvbRecordingModel::scanChannels()
 {
-qInfo() << "DvbRecordingModel::scanChannels executed";
-if (shouldWeScanChannels()) {
-	DvbChannelModel *channelModel = manager->getChannelModel();
-	QMap<int, DvbSharedChannel> channelMap = channelModel->getChannels();
-	foreach (int channelInt, channelMap.keys()) {
-		DvbSharedChannel channel;
+	qDebug("auto-scan channels");
 
-		if (channelInt > 0) {
-			channel = channelModel->findChannelByNumber(channelInt);
-		}
-		if (channel.isValid()) {
-			// TODO update tab
-			qInfo() << "DvbRecordingModel::scanChannels executed" << channel->name;
-			manager->getLiveView()->playChannel(channel);
-			delay(5);
+	if (shouldWeScanChannels()) {
+		DvbChannelModel *channelModel = manager->getChannelModel();
+		QMap<int, DvbSharedChannel> channelMap = channelModel->getChannels();
+		foreach (int channelInt, channelMap.keys()) {
+			DvbSharedChannel channel;
+
+			if (channelInt > 0) {
+				channel = channelModel->findChannelByNumber(channelInt);
+			}
+			if (channel.isValid()) {
+				// TODO update tab
+				qDebug("Executed %s", qPrintable(channel->name));
+				manager->getLiveView()->playChannel(channel);
+				delay(5);
+			}
 		}
 	}
 }
-}
 
 bool DvbRecordingModel::updateStatus(DvbRecording &recording)
 {
@@ -817,8 +818,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 			if (file.open(QIODevice::WriteOnly)) {
 				break;
 			} else {
-				qInfo() << "DvbRecordingFile::start: cannot open file" <<
-					file.fileName();
+				qWarning("Cannot open file %s. Error: %d", qPrintable(file.fileName()), errno);
 			}
 
 			if ((attempt == 0) && !QDir(folder).exists()) {
@@ -826,8 +826,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 					attempt = -1;
 					continue;
 				} else {
-					qInfo() << "DvbRecordingFile::start: cannot create folder" <<
-						folder;
+					qWarning("Cannot create folder %s", qPrintable(folder));
 				}
 			}
 
@@ -860,7 +859,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 		}
 
 		if (!file.isOpen()) {
-			qInfo() << "DvbRecordingFile::start: cannot open file" << file.fileName();
+			qWarning("Cannot open file %s", qPrintable(file.fileName()));
 			return false;
 		}
 	}
@@ -871,7 +870,7 @@ bool DvbRecordingFile::start(DvbRecording &recording)
 			DvbManager::Prioritized);
 
 		if (device == NULL) {
-			qInfo() << "DvbRecordingFile::start: cannot find a suitable device";
+			qWarning("Cannot find a suitable device");
 			return false;
 		}
 
