@@ -18,12 +18,14 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
 #endif
 
 #include <QBitArray>
+#include <QVector>
 #include <stdint.h>
 
 #include "dvbdevice.h"
@@ -59,7 +61,7 @@ public:
 class DvbScanFilter : public DvbSectionFilter, QObject
 {
 public:
-	DvbScanFilter(DvbScan *scan_) : scan(scan_), pid(-1) { }
+	DvbScanFilter(DvbScan *scan_, bool useOtherNit_) : scan(scan_), pid(-1), useOtherNit(useOtherNit_) { }
 
 	~DvbScanFilter()
 	{
@@ -75,7 +77,13 @@ public:
 	void stopFilter();
 
 private:
+	struct sectCheck {
+		int id;
+		QBitArray check;
+	};
+
 	bool checkMultipleSection(const DvbStandardSection &section);
+	bool isFinished();
 	void processSection(const char *data, int size);
 	void timerEvent(QTimerEvent *);
 
@@ -83,8 +91,9 @@ private:
 
 	int pid;
 	DvbScan::FilterType type;
-	QBitArray multipleSections;
+	QVector<sectCheck> multipleSections;
 	int timerId;
+	bool useOtherNit;
 };
 
 bool DvbScanFilter::startFilter(int pid_, DvbScan::FilterType type_)
@@ -115,6 +124,7 @@ void DvbScanFilter::stopFilter()
 	if (pid != -1) {
 		killTimer(timerId);
 		scan->device->removeSectionFilter(pid, this);
+		multipleSections.clear();
 
 		pid = -1;
 	}
@@ -123,30 +133,54 @@ void DvbScanFilter::stopFilter()
 bool DvbScanFilter::checkMultipleSection(const DvbStandardSection &section)
 {
 	int sectionCount = section.lastSectionNumber() + 1;
+	int tableNumber = -1;
+	int id = section.tableId() << 16 | section.tableIdExtension();
+
+	for (int i = 0; i < multipleSections.size(); i++) {
+		if (multipleSections.at(i).id == id) {
+			tableNumber = i;
+			break;
+		}
+	}
+	if (tableNumber < 0) {
+		tableNumber = multipleSections.size();
+		multipleSections.resize(tableNumber + 1);
+		multipleSections[tableNumber].id = id;
+		multipleSections[tableNumber].check.resize(sectionCount);
+	}
 
 	if (section.sectionNumber() >= sectionCount) {
-		qInfo() << "DvbScanFilter::checkMultipleSection: current > last";
+		qWarning("Current section is bigger than the last one");
 		sectionCount = section.sectionNumber() + 1;
 	}
 
-	if (multipleSections.isEmpty()) {
-		multipleSections.resize(sectionCount);
-	} else {
-		if (multipleSections.size() != sectionCount) {
-			qInfo() << "DvbScanFilter::checkMultipleSection: "
-			    "inconsistent number of sections";
+	QBitArray *check = &multipleSections[tableNumber].check;
 
-			if (multipleSections.size() < sectionCount) {
-				multipleSections.resize(sectionCount);
-			}
+	if (check->isEmpty()) {
+		check->resize(sectionCount);
+	} else {
+		if (check->size() != sectionCount) {
+			qWarning("Inconsistent number of sections");
+
+			if (check->size() < sectionCount)
+				check->resize(sectionCount);
 		}
 	}
 
-	if (multipleSections.testBit(section.sectionNumber())) {
+	if (check->testBit(section.sectionNumber())) {
 		return false;
 	}
 
-	multipleSections.setBit(section.sectionNumber());
+	check->setBit(section.sectionNumber());
+	return true;
+}
+
+bool DvbScanFilter::isFinished()
+{
+	for (int i = 0; i < multipleSections.size(); i++) {
+		if (multipleSections[i].check.count(false) != 0)
+			return false;
+	}
 	return true;
 }
 
@@ -184,8 +218,11 @@ void DvbScanFilter::processSection(const char *data, int size)
 		break;
 	    }
 	case DvbScan::SdtFilter: {
+		// FIXME: should we also handle other SDT table?
+
 		DvbSdtSection sdtSection(data, size);
 
+
 		if (!sdtSection.isValid() || (sdtSection.tableId() != 0x42)) {
 			// there are also other tables in the SDT
 			return;
@@ -219,10 +256,14 @@ void DvbScanFilter::processSection(const char *data, int size)
 	case DvbScan::NitFilter: {
 		DvbNitSection nitSection(data, size);
 
-		if (!nitSection.isValid() || (nitSection.tableId() != 0x40)) {
-			// we are only interested in the current network
+
+		if (!nitSection.isValid())
 			return;
-		}
+
+		if (!((nitSection.tableId() == 0x40) || (useOtherNit && (nitSection.tableId() == 0x41))))
+			return;
+
+		qDebug("Handling NIT table ID 0x%02x, extension 0x%04x", nitSection.tableId(), nitSection.tableIdExtension());
 
 		if (!checkMultipleSection(nitSection)) {
 			// already read this part
@@ -234,35 +275,37 @@ void DvbScanFilter::processSection(const char *data, int size)
 	    }
 	}
 
-	if (multipleSections.count(false) == 0) {
+	if (isFinished())
 		scan->filterFinished(this);
-	}
 }
 
 void DvbScanFilter::timerEvent(QTimerEvent *)
 {
-	qInfo() << "DvbScanFilter::timerEvent: timeout while reading section; type =" << type <<
-		QLatin1String("pid =") << pid;
+	qWarning("Timeout while reading section; type = %d, PID = %d", type, pid);
 	scan->filterFinished(this);
 }
 
-DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const DvbTransponder &transponder_) :
-	device(device_), source(source_), transponder(transponder_), isLive(true), isAuto(false),
+DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const DvbTransponder &transponder_, bool useOtherNit_) :
+	device(device_), source(source_), transponder(transponder_), isLive(true), isAuto(false), useOtherNit(useOtherNit_),
 	transponderIndex(-1), state(ScanPat), patIndex(0), activeFilters(0)
 {
+	qDebug("Use other NIT is %s", useOtherNit ? "enabled" : "disabled");
 }
 
 DvbScan::DvbScan(DvbDevice *device_, const QString &source_,
-	const QList<DvbTransponder> &transponders_) : device(device_), source(source_),
-	isLive(false), isAuto(false), transponders(transponders_), transponderIndex(0),
+	const QList<DvbTransponder> &transponders_, bool useOtherNit_) : device(device_), source(source_),
+	isLive(false), isAuto(false), useOtherNit(useOtherNit_), transponders(transponders_), transponderIndex(0),
 	state(ScanTune), patIndex(0), activeFilters(0)
 {
+	qDebug("Use other NIT is %s", useOtherNit ? "enabled" : "disabled");
 }
 
-DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &autoScanSource) :
-	device(device_), source(source_), isLive(false), isAuto(true), transponderIndex(0),
+DvbScan::DvbScan(DvbDevice *device_, const QString &source_, const QString &autoScanSource, bool useOtherNit_) :
+	device(device_), source(source_), isLive(false), isAuto(true), useOtherNit(useOtherNit_), transponderIndex(0),
 	state(ScanTune), patIndex(0), activeFilters(0)
 {
+	qDebug("Use other NIT is %s", useOtherNit ? "enabled" : "disabled");
+
 	if ((autoScanSource == QLatin1String("AUTO-Normal")) || (autoScanSource == QLatin1String("AUTO-Offsets"))) {
 		bool offsets = (autoScanSource == QLatin1String("AUTO-Offsets"));
 
@@ -451,6 +494,7 @@ void DvbScan::start()
 void DvbScan::deviceStateChanged()
 {
 	if (device->getDeviceState() == DvbDevice::DeviceReleased) {
+		qWarning("Device was released. Stopping scan");
 		emit scanFinished();
 		return;
 	}
@@ -476,7 +520,7 @@ bool DvbScan::startFilter(int pid, FilterType type)
 
 		Q_ASSERT(false);
 	} else if (activeFilters < 10) {
-		DvbScanFilter *filter = new DvbScanFilter(this);
+		DvbScanFilter *filter = new DvbScanFilter(this, useOtherNit);
 
 		if (!filter->startFilter(pid, type)) {
 			delete filter;
@@ -500,7 +544,7 @@ void DvbScan::updateState()
 				return;
 			}
 
-			snr = device->getSnr();
+			snr = device->getSnr(scale);
 
 			state = ScanNit;
 		    }
@@ -561,6 +605,7 @@ void DvbScan::updateState()
 						       arg(channel.transportStreamId).
 						       arg(channel.serviceId);
 				}
+				qDebug("Found channel %s", qPrintable(channel.name));
 			}
 
 			if (!channels.isEmpty()) {
@@ -568,6 +613,7 @@ void DvbScan::updateState()
 			}
 
 			if (isLive) {
+				qInfo("Scanning while live stream. Can't change the transponder");
 				emit scanFinished();
 				return;
 			}
@@ -585,6 +631,7 @@ void DvbScan::updateState()
 				emit scanProgress((100 * transponderIndex) / transponders.size());
 			}
 
+			qDebug("Transponder %d/%d", transponderIndex, transponders.size());
 			if (transponderIndex >= transponders.size()) {
 				emit scanFinished();
 				return;
@@ -637,6 +684,8 @@ void DvbScan::processPat(const DvbPatSection &section)
 		if (entry.programNumber() != 0x0) {
 			// skip 0x0 which has a special meaning
 			patEntries.append(DvbPatEntry(entry.programNumber(), entry.pid()));
+
+			qDebug("New PAT entry: pid %d, program %d", entry.pid(), entry.programNumber());
 		}
 	}
 }
@@ -659,8 +708,24 @@ void DvbScan::processPmt(const DvbPmtSection &section, int pid)
 		channel.pmtPid = pid;
 		channel.pmtSectionData = section.toByteArray();
 		channel.serviceId = section.programNumber();
-		channel.snr = snr;
+		switch (scale) {
+		case DvbBackendDevice::dBuV:
+		case DvbBackendDevice::NotSupported: {
+			channel.snr = "";
+			break;
+		}
+		case DvbBackendDevice::Percentage: {
+			channel.snr = QString::number(snr, 'f', 0) + "%";
+			break;
+		}
+		case DvbBackendDevice::Decibel: {
+			channel.snr = QString::number(snr, 'f', 2) + " dB";
+			break;
+		}
+		};
 		channels.append(channel);
+
+		qDebug("New channel: PID %d, service ID %d", pid, section.programNumber());
 	}
 }
 
@@ -684,19 +749,19 @@ void DvbScan::processSdt(const DvbSdtSection &section)
 
 			sdtEntry.name = serviceDescriptor.serviceName();
 			sdtEntry.provider = serviceDescriptor.providerName();
-			break;
-		}
 
-		sdtEntries.append(sdtEntry);
+			qDebug("New SDT entry: service ID 0x%04x, name '%s', provider '%s'", entry.serviceId(), qPrintable(sdtEntry.name), qPrintable(sdtEntry.provider));
+			sdtEntries.append(sdtEntry);
+		}
 	}
 }
 
 void DvbScan::processVct(const AtscVctSection &section)
 {
-	int i = section.entryCount();
+	AtscVctSectionEntry entry = section.entries();
+	int entryCount = section.entryCount();
 
-	for (AtscVctSectionEntry entry = section.entries(); (i > 0) && (entry.isValid());
-	     --i, entry.advance()) {
+	for (int i = 0; i < entryCount && (entry.isValid()); i++) {
 		QString majorminor = QString(QLatin1String("%1-%2 ")).
 			arg(entry.majorNumber(), 3, 10, QLatin1Char('0')).arg(entry.minorNumber());
 
@@ -706,35 +771,38 @@ void DvbScan::processVct(const AtscVctSection &section)
 		// See A/65C table 6.25a for the list of descriptors
 		for (DvbDescriptor descriptor = entry.descriptors(); descriptor.isValid();
 		     descriptor.advance()) {
-			if (descriptor.descriptorTag() != 0xa0) {
-				continue;
+			if (descriptor.descriptorTag() == 0xa0) {
+				// Extended Channel Name Descriptor
+				AtscChannelNameDescriptor nameDescriptor(descriptor);
+				if (!nameDescriptor.isValid()) {
+					continue;
+				}
+				sdtEntry.name = majorminor + nameDescriptor.name();
 			}
-
-			// Extended Channel Name Descriptor
-			AtscChannelNameDescriptor nameDescriptor(descriptor);
-			if (!nameDescriptor.isValid()) {
-				continue;
-			}
-			sdtEntry.name = majorminor + nameDescriptor.name();
 		}
 
 		if (sdtEntry.name.isEmpty()) {
 			// Extended Channel name not available, fall back
 			// to the short name
 			QChar shortName[] = { entry.shortName1(),
-					      entry.shortName2(),
-					      entry.shortName3(),
-					      entry.shortName4(),
-					      entry.shortName5(),
-					      entry.shortName6(),
-					      entry.shortName7(), 0 };
+						entry.shortName2(),
+						entry.shortName3(),
+						entry.shortName4(),
+						entry.shortName5(),
+						entry.shortName6(),
+						entry.shortName7(), 0 };
 			int nameLength = 0;
 			while (shortName[nameLength] != 0) {
 				++nameLength;
 			}
 			sdtEntry.name = majorminor + QString(shortName, nameLength);
 		}
+
+		qDebug("New SDT entry: name %s", qPrintable(sdtEntry.name));
 		sdtEntries.append(sdtEntry);
+
+		if (i < entryCount - 1)
+			entry.advance();
 	}
 }
 
@@ -981,17 +1049,17 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 
 	switch (transponder.getTransmissionType()) {
 	case DvbTransponderBase::Invalid:
-		qInfo() << "DvbScan::processNitDescriptor: Invalid transponder type";
-		break;
+		qWarning("Invalid transponder type");
+		return;
 	case DvbTransponderBase::DvbC: {
 		if (descriptor.descriptorTag() != 0x44) {
-			break;
+			return;
 		}
 
 		DvbCableDescriptor cableDescriptor(descriptor);
 
 		if (!cableDescriptor.isValid()) {
-			break;
+			return;
 		}
 
 		newTransponder = DvbTransponder(DvbTransponderBase::DvbC);
@@ -1002,18 +1070,20 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 			DvbDescriptor::bcdToInt(cableDescriptor.symbolRate(), 100);
 		dvbCTransponder->modulation = extractDvbCModulation(cableDescriptor);
 		dvbCTransponder->fecRate = extractDvbCFecRate(cableDescriptor);
+
+		qDebug("Added transponder: %.2f MHz", dvbCTransponder->frequency / 1000000.);
 		break;
 	    }
 	case DvbTransponderBase::DvbS:
 	case DvbTransponderBase::DvbS2: {
 		if (descriptor.descriptorTag() != 0x43) {
-			break;
+			return;
 		}
 
 		DvbSatelliteDescriptor satelliteDescriptor(descriptor);
 
 		if (!satelliteDescriptor.isValid()) {
-			break;
+			return;
 		}
 
 		DvbSTransponder *dvbSTransponder;
@@ -1023,7 +1093,7 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 			dvbSTransponder = newTransponder.as<DvbSTransponder>();
 		} else {
 			if ((device->getTransmissionTypes() & DvbDevice::DvbS2) == 0) {
-				break;
+				return;
 			}
 
 			newTransponder = DvbTransponder(DvbTransponderBase::DvbS2);
@@ -1039,6 +1109,8 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 		dvbSTransponder->symbolRate =
 			DvbDescriptor::bcdToInt(satelliteDescriptor.symbolRate(), 100);
 		dvbSTransponder->fecRate = extractDvbSFecRate(satelliteDescriptor);
+
+		qDebug("Added transponder: %.2f MHz", dvbSTransponder->frequency / 1000000.);
 		break;
 	    }
 	case DvbTransponderBase::DvbT2:
@@ -1047,13 +1119,13 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 
 	case DvbTransponderBase::DvbT: {
 		if (descriptor.descriptorTag() != 0x5a) {
-			break;
+			return;
 		}
 
 		DvbTerrestrialDescriptor terrestrialDescriptor(descriptor);
 
 		if (!terrestrialDescriptor.isValid()) {
-			break;
+			return;
 		}
 
 		newTransponder = DvbTransponder(DvbTransponderBase::DvbT);
@@ -1072,32 +1144,41 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 			dvbTTransponder->fecRateLow = DvbTTransponder::FecNone;
 		}
 
+		qDebug("Added transponder: %.2f MHz", dvbTTransponder->frequency / 1000000.);
 		break;
 	    }
 	case DvbTransponderBase::Atsc:
-		break;
+		return;
 	case DvbTransponderBase::IsdbT:
 		if (descriptor.descriptorTag() != 0xfa) {
-			break;
+			return;
 		}
 
 		IsdbTerrestrialDescriptor IsdbTDescriptor(descriptor);
 
 		if (!IsdbTDescriptor.isValid()) {
-			break;
+			return;
 		}
 
-#if 0
-		/* What to do with descriptors for the current transponder? */
-		IsdbTDescriptor->guardInterval = extractIsdbTGuardInterval(IsdbTDescriptor);
-		IsdbTDescriptor->transmissionMode = extractIsdbTTransmissionMode(IsdbTDescriptor);
-#endif
 		for (int i = 0; i < IsdbTDescriptor.frequencyLength(); i++) {
 			newTransponder = DvbTransponder(DvbTransponderBase::IsdbT);
 			IsdbTTransponder *isdbTTransponder = newTransponder.as<IsdbTTransponder>();
 
 			isdbTTransponder->frequency =
 				(uint32_t)((((uint64_t)IsdbTDescriptor.frequency(i)) * 1000000ul) / 7);
+			isdbTTransponder->bandwidth = IsdbTTransponder::Bandwidth6MHz;
+			isdbTTransponder->transmissionMode = IsdbTTransponder::TransmissionModeAuto;
+			isdbTTransponder->guardInterval = IsdbTTransponder::GuardIntervalAuto;
+			isdbTTransponder->partialReception = IsdbTTransponder::PR_AUTO;
+			isdbTTransponder->soundBroadcasting = IsdbTTransponder::SB_disabled;
+			for (int i = 0; i < 3; i++) {
+				isdbTTransponder->layerEnabled[i] = true;
+				isdbTTransponder->modulation[i] = IsdbTTransponder::ModulationAuto;
+				isdbTTransponder->fecRate[i] = IsdbTTransponder::FecAuto;
+				isdbTTransponder->interleaving[i] = IsdbTTransponder::I_AUTO;
+				isdbTTransponder->segmentCount[i] = 15;
+			}
+
 			bool duplicate = false;
 
 			foreach (const DvbTransponder &existingTransponder, transponders) {
@@ -1106,28 +1187,23 @@ void DvbScan::processNitDescriptor(const DvbDescriptor &descriptor)
 					break;
 				}
 			}
-			if (!duplicate)
-				transponders.append(newTransponder);
-		}
-		newTransponder = DvbTransponder(DvbTransponderBase::IsdbT);
+			if (duplicate)
+				continue;
 
-		break;
-	}
-
-	if (newTransponder.isValid()) {
-		bool duplicate = false;
-
-		foreach (const DvbTransponder &existingTransponder, transponders) {
-			if (existingTransponder.corresponds(newTransponder)) {
-				duplicate = true;
-				break;
-			}
-		}
-
-		if (!duplicate) {
 			transponders.append(newTransponder);
+			qDebug("Added transponder: %.2f MHz", isdbTTransponder->frequency / 1000000.);
 		}
+		return;
 	}
+
+
+	// New transponder was found. Add it
+	foreach (const DvbTransponder &existingTransponder, transponders) {
+		if (existingTransponder.corresponds(newTransponder))
+			return;
+	}
+
+	transponders.append(newTransponder);
 }
 
 void DvbScan::filterFinished(DvbScanFilter *filter)
