@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -37,7 +38,7 @@ void DvbSection::initSection(const char *data, int size)
 	int sectionLength = ((((quint8(data[1]) & 0xf) << 8) | quint8(data[2])) + 3);
 
 	if (sectionLength > size) {
-		qInfo() << "DvbSection::initSection: adjusting length";
+		qInfo("Adjusting length");
 		sectionLength = size;
 	}
 
@@ -241,15 +242,26 @@ const unsigned short Iso6937Codec::table[] = {
 
 QString DvbSiText::convertText(const char *data, int size)
 {
+	TextEncoding encoding = Iso6937;
+
 	if (size < 1) {
 		return QString();
 	}
 
-	// determine encoding
-	TextEncoding encoding = (override6937 ? Iso8859_1 : Iso6937);
+	if (size >2 && data[0] == 0x0e && data[size - 1] == 0x0f ) {
+		// Remove LS0 and LS1 codes found on some ISDB-T streams
+		data++;
+		size -= 2;
+
+		encoding = Iso8859_1;
+	}
+
+	if (override6937)
+		encoding = Iso8859_1;
 
 	if (quint8(data[0]) < 0x20) {
 		switch (data[0]) {
+		case 0x00: encoding = Iso6937; break;
 		case 0x01: encoding = Iso8859_5; break;
 		case 0x02: encoding = Iso8859_6; break;
 		case 0x03: encoding = Iso8859_7; break;
@@ -260,8 +272,10 @@ QString DvbSiText::convertText(const char *data, int size)
 		case 0x09: encoding = Iso8859_13; break;
 		case 0x0a: encoding = Iso8859_14; break;
 		case 0x0b: encoding = Iso8859_15; break;
+		case 0x11: encoding = Iso10646_ucs2; break;
+		case 0x12: encoding = Iso2022_kr; break;
 		case 0x13: encoding = Gb2312; break;
-		case 0x14: encoding = Big5; break;
+		case 0x14: encoding = Utf_16be; break;
 		case 0x15: encoding = Utf_8; break;
 		case 0x10: {
 			if (size < 3) {
@@ -320,8 +334,10 @@ QString DvbSiText::convertText(const char *data, int size)
 		case Iso8859_13: codec = QTextCodec::codecForName("ISO 8859-13"); break;
 		case Iso8859_14: codec = QTextCodec::codecForName("ISO 8859-14"); break;
 		case Iso8859_15: codec = QTextCodec::codecForName("ISO 8859-15"); break;
+		case Iso10646_ucs2: codec = QTextCodec::codecForName("UTF-16"); break;
+		case Iso2022_kr: codec = QTextCodec::codecForName("ISO 2022-KR"); break;
 		case Gb2312: codec = QTextCodec::codecForName("GB2312"); break;
-		case Big5: codec = QTextCodec::codecForName("BIG5"); break;
+		case Utf_16be: codec = QTextCodec::codecForName("UTF-16BE"); break;
 		case Utf_8: codec = QTextCodec::codecForName("UTF-8"); break;
 		}
 
@@ -364,7 +380,7 @@ void DvbDescriptor::initDescriptor(const char *data, int size)
 {
 	if (size < 2) {
 		if (size != 0) {
-			qInfo() << "DvbDescriptor::initDescriptor: invalid descriptor";
+			qInfo("Invalid descriptor");
 		}
 
 		initSectionData();
@@ -374,7 +390,7 @@ void DvbDescriptor::initDescriptor(const char *data, int size)
 	int descriptorLength = (quint8(data[1]) + 2);
 
 	if (descriptorLength > size) {
-		qInfo() << "DvbDescriptor::initDescriptor: adjusting length";
+		qInfo("Adjusting length");
 		descriptorLength = size;
 	}
 
@@ -408,7 +424,7 @@ QString AtscPsipText::interpretTextData(const char *data, unsigned int len,
 		// 0x3e Standard Compression Scheme for UNICODE (SCSU)
 		// 0x40/0x41 Taiwan
 		// 0x48 South Korea
-		qInfo() << "AtscPsipText::interpretTextData: Unsupported ATSC Text mode" << mode;
+		qInfo("Unsupported ATSC Text mode %d", mode);
 	}
 	return result;
 }
@@ -435,7 +451,7 @@ QString AtscPsipText::convertText(const char *data, int size)
 	offset += 3;
 
 	if (offset > size) {
-		qInfo() << "AtscPsipText::convertText: adjusting length";
+		qInfo("Adjusting length");
 		return result;
 	}
 
@@ -443,7 +459,7 @@ QString AtscPsipText::convertText(const char *data, int size)
 
 	for (int j = 0; j < num_segments; j++) {
 		if ((offset + 3) > size) {
-			qInfo() << "AtscPsipText::convertText: adjusting length";
+			qInfo("Adjusting length");
 			return result;
 		}
 
@@ -452,7 +468,7 @@ QString AtscPsipText::convertText(const char *data, int size)
 		int num_bytes = quint8(data[offset++]);
 
 		if ((offset + num_bytes) > size) {
-			qInfo() << "AtscPsipText::convertText: adjusting length";
+			qInfo("Adjusting length");
 			return result;
 		}
 
@@ -469,8 +485,7 @@ QString AtscPsipText::convertText(const char *data, int size)
 			result +=
 				AtscHuffmanString::convertText(comp_string, num_bytes, comp_type);
 		} else {
-			qInfo() << "AtscPsipText::convertText: Unsupported compression / mode" <<
-				comp_type << mode;
+			qInfo("Usupported compression / mode %d %d", comp_type, mode);
 		}
 
 		offset += num_bytes;
@@ -1183,7 +1198,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				if ((subtitleDescriptor.subtitleType() >= 0x01) &&
 				    (subtitleDescriptor.subtitleType() <= 0x03)) {
 					// FIXME how to deal with vbi and teletext subtitles?
-					qInfo() << "DvbPmtParser::DvbPmtParser: special subtitle found";
+					qInfo("Unsupported subtitle found: VBI/teletext (%d)", subtitleDescriptor.subtitleType());
 				}
 
 				// ISO 8859-1 equals to unicode range 0x0000 - 0x00ff
@@ -1209,7 +1224,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 			if (videoPid < 0) {
 				videoPid = entry.pid();
 			} else {
-				qInfo() << "DvbPmtParser::DvbPmtParser: more than one video pid";
+				qInfo("More than one video PID");
 			}
 
 			break;
@@ -1228,8 +1243,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				if (teletextPid < 0) {
 					teletextPid = entry.pid();
 				} else {
-					qInfo() << "DvbPmtParser::DvbPmtParser: "
-					    "more than one teletext pid";
+					qInfo("More than one teletext PID");
 				}
 			}
 
@@ -1237,8 +1251,7 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 				subtitlePids.append(qMakePair(entry.pid(), subtitleLanguage));
 
 				if (teletextPresent) {
-					qInfo() << "DvbPmtParser::DvbPmtParser: "
-					    "subtitle and teletext on the same pid";
+					qInfo("Subtitle and teletext on the same PID");
 				}
 			}
 
@@ -1250,13 +1263,11 @@ DvbPmtParser::DvbPmtParser(const DvbPmtSection &section) : videoPid(-1), teletex
 
 		default:
 			if (!subtitleLanguage.isEmpty()) {
-				qInfo() << "DvbPmtParser::DvbPmtParser: "
-				    "subtitle with unexpected stream type found";
+				qInfo("Subtitle with unexpected stream type found");
 			}
 
 			if (teletextPresent) {
-				qInfo() << "DvbPmtParser::DvbPmtParser: "
-				    "teletext with unexpected stream type found";
+				qInfo("Teletext with unexpected stream type found");
 			}
 
 			break;
@@ -1268,7 +1279,7 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 {
 	if (size < 12) {
 		if (size != 0) {
-			qInfo() << "AtscEitSectionEntry::initEitSectionEntry: invalid entry";
+			qInfo("Invalid entry");
 		}
 
 		initSectionData();
@@ -1278,7 +1289,7 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 	titleLength = quint8(data[9]);
 
 	if (titleLength > (size - 12)) {
-		qInfo() << "AtscEitSectionEntry::initEitSectionEntry: adjusting length";
+		qInfo("Adjusting length");
 		titleLength = (size - 12);
 	}
 
@@ -1287,7 +1298,7 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 		quint8(data[11 + titleLength])) + 12 + titleLength);
 
 	if (entryLength > size) {
-		qInfo() << "AtscEitSectionEntry::initEitSectionEntry: adjusting length";
+		qInfo("Adjusting length");
 		entryLength = size;
 	}
 
@@ -1296,143 +1307,11 @@ void AtscEitSectionEntry::initEitSectionEntry(const char *data, int size)
 
 // everything below this line is automatically generated
 
-DvbLanguageDescriptor::DvbLanguageDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 6) {
-		qInfo() << "DvbLanguageDescriptor::DvbLanguageDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-DvbSubtitleDescriptor::DvbSubtitleDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 10) {
-		qInfo() << "DvbSubtitleDescriptor::DvbSubtitleDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-DvbServiceDescriptor::DvbServiceDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 5) {
-		qInfo() << "DvbServiceDescriptor::DvbServiceDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-
-	providerNameLength = at(3);
-
-	if (providerNameLength > (getLength() - 5)) {
-		qInfo() << "DvbServiceDescriptor::DvbServiceDescriptor: adjusting length";
-		providerNameLength = (getLength() - 5);
-	}
-
-	serviceNameLength = at(4 + providerNameLength);
-
-	if (serviceNameLength > (getLength() - (5 + providerNameLength))) {
-		qInfo() << "DvbServiceDescriptor::DvbServiceDescriptor: adjusting length";
-		serviceNameLength = (getLength() - (5 + providerNameLength));
-	}
-}
-
-DvbShortEventDescriptor::DvbShortEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 7) {
-		qInfo() << "DvbShortEventDescriptor::DvbShortEventDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-
-	eventNameLength = at(5);
-
-	if (eventNameLength > (getLength() - 7)) {
-		qInfo() << "DvbShortEventDescriptor::DvbShortEventDescriptor: adjusting length";
-		eventNameLength = (getLength() - 7);
-	}
-
-	textLength = at(6 + eventNameLength);
-
-	if (textLength > (getLength() - (7 + eventNameLength))) {
-		qInfo() << "DvbShortEventDescriptor::DvbShortEventDescriptor: adjusting length";
-		textLength = (getLength() - (7 + eventNameLength));
-	}
-}
-
-DvbExtendedEventDescriptor::DvbExtendedEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 8) {
-		qInfo() << "DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-
-	itemsLength = at(6);
-
-	if (itemsLength > (getLength() - 8)) {
-		qInfo() << "DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: adjusting length";
-		itemsLength = (getLength() - 8);
-	}
-
-	textLength = at(7 + itemsLength);
-
-	if (textLength > (getLength() - (8 + itemsLength))) {
-		qInfo() << "DvbExtendedEventDescriptor::DvbExtendedEventDescriptor: adjusting length";
-		textLength = (getLength() - (8 + itemsLength));
-	}
-}
-
-DvbCableDescriptor::DvbCableDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 13) {
-		qInfo() << "DvbCableDescriptor::DvbCableDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-DvbSatelliteDescriptor::DvbSatelliteDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 13) {
-		qInfo() << "DvbSatelliteDescriptor::DvbSatelliteDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-DvbTerrestrialDescriptor::DvbTerrestrialDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 13) {
-		qInfo() << "DvbTerrestrialDescriptor::DvbTerrestrialDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-IsdbTerrestrialDescriptor::IsdbTerrestrialDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 4) {
-		qInfo() << "IsdbTerrestrialDescriptor::IsdbTerrestrialDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
-AtscChannelNameDescriptor::AtscChannelNameDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
-{
-	if (getLength() < 2) {
-		qInfo() << "AtscChannelNameDescriptor::AtscChannelNameDescriptor: invalid descriptor";
-		initSectionData();
-		return;
-	}
-}
-
 void DvbPatSectionEntry::initPatSectionEntry(const char *data, int size)
 {
 	if (size < 4) {
 		if (size != 0) {
-			qInfo() << "DvbPatSectionEntry::initPatSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1446,7 +1325,7 @@ void DvbPmtSectionEntry::initPmtSectionEntry(const char *data, int size)
 {
 	if (size < 5) {
 		if (size != 0) {
-			qInfo() << "DvbPmtSectionEntry::initPmtSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1456,7 +1335,7 @@ void DvbPmtSectionEntry::initPmtSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[3]) & 0xf) << 8) | quint8(data[4])) + 5);
 
 	if (entryLength > size) {
-		qInfo() << "DvbPmtSectionEntry::initPmtSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
@@ -1467,7 +1346,7 @@ void DvbSdtSectionEntry::initSdtSectionEntry(const char *data, int size)
 {
 	if (size < 5) {
 		if (size != 0) {
-			qInfo() << "DvbSdtSectionEntry::initSdtSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1477,7 +1356,7 @@ void DvbSdtSectionEntry::initSdtSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[3]) & 0xf) << 8) | quint8(data[4])) + 5);
 
 	if (entryLength > size) {
-		qInfo() << "DvbSdtSectionEntry::initSdtSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
@@ -1488,7 +1367,7 @@ void DvbEitSectionEntry::initEitSectionEntry(const char *data, int size)
 {
 	if (size < 12) {
 		if (size != 0) {
-			qInfo() << "DvbEitSectionEntry::initEitSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1498,18 +1377,46 @@ void DvbEitSectionEntry::initEitSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[10]) & 0xf) << 8) | quint8(data[11])) + 12);
 
 	if (entryLength > size) {
-		qInfo() << "DvbEitSectionEntry::initEitSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
 	initSectionData(data, entryLength, size);
 }
 
+void DvbEitContentEntry::initEitContentEntry(const char *data, int size)
+{
+	if (size < 2) {
+		if (size != 0) {
+		qWarning("Invalid entry at descriptor");
+		}
+
+		initSectionData();
+		return;
+	}
+
+	initSectionData(data, 2, size);
+}
+
+void DvbParentalRatingEntry::initParentalRatingEntry(const char *data, int size)
+{
+	if (size < 4) {
+		if (size != 0) {
+		qWarning("Invalid entry at descriptor");
+		}
+
+		initSectionData();
+		return;
+	}
+
+	initSectionData(data, 4, size);
+}
+
 void DvbNitSectionEntry::initNitSectionEntry(const char *data, int size)
 {
 	if (size < 6) {
 		if (size != 0) {
-			qInfo() << "DvbNitSectionEntry::initNitSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1519,7 +1426,7 @@ void DvbNitSectionEntry::initNitSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[4]) & 0xf) << 8) | quint8(data[5])) + 6);
 
 	if (entryLength > size) {
-		qInfo() << "DvbNitSectionEntry::initNitSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
@@ -1530,7 +1437,7 @@ void AtscMgtSectionEntry::initMgtSectionEntry(const char *data, int size)
 {
 	if (size < 11) {
 		if (size != 0) {
-			qInfo() << "AtscMgtSectionEntry::initMgtSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1540,7 +1447,7 @@ void AtscMgtSectionEntry::initMgtSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[9]) & 0xf) << 8) | quint8(data[10])) + 11);
 
 	if (entryLength > size) {
-		qInfo() << "AtscMgtSectionEntry::initMgtSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
@@ -1551,7 +1458,7 @@ void AtscVctSectionEntry::initVctSectionEntry(const char *data, int size)
 {
 	if (size < 32) {
 		if (size != 0) {
-			qInfo() << "AtscVctSectionEntry::initVctSectionEntry: invalid entry";
+		qWarning("Invalid entry at descriptor");
 		}
 
 		initSectionData();
@@ -1561,13 +1468,163 @@ void AtscVctSectionEntry::initVctSectionEntry(const char *data, int size)
 	int entryLength = ((((quint8(data[30]) & 0x3) << 8) | quint8(data[31])) + 32);
 
 	if (entryLength > size) {
-		qInfo() << "AtscVctSectionEntry::initVctSectionEntry: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entryLength = size;
 	}
 
 	initSectionData(data, entryLength, size);
 }
 
+DvbLanguageDescriptor::DvbLanguageDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 6) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbSubtitleDescriptor::DvbSubtitleDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 10) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbServiceDescriptor::DvbServiceDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 5) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+
+	providerNameLength = at(3);
+
+	if (providerNameLength > (getLength() - 5)) {
+		qWarning("Adjusting length on descriptor");
+		providerNameLength = (getLength() - 5);
+	}
+
+	serviceNameLength = at(4 + providerNameLength);
+
+	if (serviceNameLength > (getLength() - (5 + providerNameLength))) {
+		qWarning("Adjusting length on descriptor");
+		serviceNameLength = (getLength() - (5 + providerNameLength));
+	}
+}
+
+DvbShortEventDescriptor::DvbShortEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 7) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+
+	eventNameLength = at(5);
+
+	if (eventNameLength > (getLength() - 7)) {
+		qWarning("Adjusting length on descriptor");
+		eventNameLength = (getLength() - 7);
+	}
+
+	textLength = at(6 + eventNameLength);
+
+	if (textLength > (getLength() - (7 + eventNameLength))) {
+		qWarning("Adjusting length on descriptor");
+		textLength = (getLength() - (7 + eventNameLength));
+	}
+}
+
+DvbExtendedEventDescriptor::DvbExtendedEventDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 8) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+
+	itemsLength = at(6);
+
+	if (itemsLength > (getLength() - 8)) {
+		qWarning("Adjusting length on descriptor");
+		itemsLength = (getLength() - 8);
+	}
+
+	textLength = at(7 + itemsLength);
+
+	if (textLength > (getLength() - (8 + itemsLength))) {
+		qWarning("Adjusting length on descriptor");
+		textLength = (getLength() - (8 + itemsLength));
+	}
+}
+
+DvbContentDescriptor::DvbContentDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 2) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbParentalRatingDescriptor::DvbParentalRatingDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 2) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbCableDescriptor::DvbCableDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 13) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbSatelliteDescriptor::DvbSatelliteDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 13) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+DvbTerrestrialDescriptor::DvbTerrestrialDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 13) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+IsdbTerrestrialDescriptor::IsdbTerrestrialDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 4) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
+AtscChannelNameDescriptor::AtscChannelNameDescriptor(const DvbDescriptor &descriptor) : DvbDescriptor(descriptor)
+{
+	if (getLength() < 2) {
+		qWarning("Invalid descriptor");
+		initSectionData();
+		return;
+	}
+}
+
 void DvbPatSection::initPatSection(const char *data, int size)
 {
 	if (size < 12) {
@@ -1589,7 +1646,7 @@ void DvbPmtSection::initPmtSection(const char *data, int size)
 	descriptorsLength = ((at(10) & 0xf) << 8) | at(11);
 
 	if (descriptorsLength > (getLength() - 16)) {
-		qInfo() << "DvbPmtSection::initPmtSection: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		descriptorsLength = (getLength() - 16);
 	}
 }
@@ -1625,21 +1682,21 @@ void DvbNitSection::initNitSection(const char *data, int size)
 	descriptorsLength = ((at(8) & 0xf) << 8) | at(9);
 
 	if (descriptorsLength > (getLength() - 16)) {
-		qInfo() << "DvbNitSection::initNitSection: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		descriptorsLength = (getLength() - 16);
 	}
 
 	entriesLength = ((at(10 + descriptorsLength) & 0xf) << 8) | at(11 + descriptorsLength);
 
 	if (entriesLength > (getLength() - (16 + descriptorsLength))) {
-		qInfo() << "DvbNitSection::initNitSection: adjusting length";
+		qWarning("Adjusting length on descriptor");
 		entriesLength = (getLength() - (16 + descriptorsLength));
 	}
 }
 
 void AtscMgtSection::initMgtSection(const char *data, int size)
 {
-	if (size < 15) {
+	if (size < 17) {
 		initSectionData();
 		return;
 	}
