@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -27,5 +28,5 @@
 
 void EnsureNoPendingOperation::printFatalErrorMessage()
 {
-	qInfo() << "EnsureNoPendingOperation::printFatalErrorMessage: illegal recursive call";
+	qWarning("Illegal recursive call");
 }
