@@ -18,6 +18,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <KLocalizedString>
 #include <QDebug>
 #if QT_VERSION < 0x050500
 # define qInfo qDebug
@@ -25,11 +26,11 @@
 
 #include <KAboutData>
 #include <KDBusService>
-#include <KLocalizedString>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDateTime>
 #include <QDir>
+#include <QLoggingCategory>
 #include <QPointer>
 #include <QStandardPaths>
 #include <QString>
@@ -38,6 +39,10 @@
 
 #include <config-kaffeine.h>
 
+extern "C" {
+  #include <unistd.h>
+}
+
 #include "configurationdialog.h"
 #include "mainwindow.h"
 #include "sqlhelper.h"
@@ -49,35 +54,54 @@ void verboseMessageHandler(QtMsgType type, const QMessageLogContext &context, co
 		"[Warning ] ",
 		"[Critical] ",
 		"[Fatal   ] ",
-		"[System  ] "};
+		"[Info    ] "};
+	static const QString color[] {
+		"\x1b[0;32m",	// Debug
+		"\x1b[0;33m",	// Warning
+		"\x1b[0;31m",	// Critical
+		"\x1b[1;31m",	// Fatal
+		"\x1b[0;37m"};	// Info
 	QString contextString, file = context.file;
 	QByteArray localMsg = msg.toLocal8Bit();
 	QString log;
 
 	file.remove(QRegExp(".*/kaffeine/"));
 
-	if (context.line)
-		contextString = QStringLiteral("%1#%2: ")
+	if (context.line && QLoggingCategory::defaultCategory()->isEnabled(QtDebugMsg))
+		contextString = QStringLiteral("%1#%2: %3: ")
 						.arg(file)
-						.arg(context.line);
+						.arg(context.line)
+						.arg(context.function);
 
 	QString timeStr(QDateTime::currentDateTime().toString("dd-MM-yy HH:mm:ss.zzz "));
 
 	log.append(timeStr);
 	if (type <= 4)
 		log.append(typeStr[type]);
-	if (!contextString.isEmpty())
-		log.append(contextString);
-	log.append(localMsg.constData());
-	log.append("\n");
 
+	if (isatty(STDERR_FILENO) && (type <= 4))
+		std::cerr << color[type].toLocal8Bit().constData();
 	std::cerr << log.toLocal8Bit().constData();
 
-	Log newLog;
-	newLog.storeLog(log);
+	if (!contextString.isEmpty()) {
+		if (isatty(STDERR_FILENO))
+			std::cerr << "\x1b[0;33m";
+		std::cerr << contextString.toLocal8Bit().constData();
+	}
+
+	if (isatty(STDERR_FILENO))
+		std::cerr << "\x1b[0;37m";
+
+	std::cerr << localMsg.constData() << "\n";
 
 	if (type == QtFatalMsg)
 		abort();
+
+	log.append(localMsg.constData());
+	log.append("\n");
+
+	Log newLog;
+	newLog.storeLog(log);
 }
 
 class KaffeineApplication : public QApplication
@@ -152,32 +176,6 @@ KaffeineApplication::~KaffeineApplication()
 	delete mainWindow; // QPointer; needed if kaffeine is closed via QCoreApplication::quit()
 }
 
-// The icon Kaffeine needs are either at breeze or oxygen themes
-static void iconThemeFunc()
-
-{
-	if ((QIcon::themeName() != QLatin1String("breeze")
-	    && QIcon::themeName() != QLatin1String("oxgen"))
-	    || QIcon::themeName().isEmpty()) {
-		foreach(const QString &path, QIcon::themeSearchPaths()) {
-			QDir d(path);
-			if (d.exists(QLatin1String("breeze"))) {
-				QIcon::setThemeName(QLatin1String("breeze"));
-				return;
-			}
-		}
-		foreach(const QString &path, QIcon::themeSearchPaths()) {
-			QDir d(path);
-			if (d.exists(QLatin1String("oxygen"))) {
-				QIcon::setThemeName(QLatin1String("oxygen"));
-				return;
-			}
-		}
-	}
-}
-
-Q_COREAPP_STARTUP_FUNCTION(iconThemeFunc)
-
 int main(int argc, char *argv[])
 {
 	qInstallMessageHandler(verboseMessageHandler);
@@ -190,7 +188,7 @@ int main(int argc, char *argv[])
 
 	app.setApplicationName("kaffeine");
 	app.setOrganizationDomain("kde.org");
-	app.setWindowIcon(QIcon::fromTheme(QLatin1String("kaffeine")));
+	app.setWindowIcon(QIcon::fromTheme(QLatin1String("kaffeine"), QIcon(":kaffeine")));
 
 	app.parser.addVersionOption();
 	app.parser.addHelpOption();
